@@ -1,26 +1,26 @@
 /* ************************************************************ binary.c *** *
- * Teoeyes Plugin Collection (Ͳ)
+ * Teoeyes Plugin Collection ($B#2CM2=(B)
  *
- * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2001-2004 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                  Time-stamp: <2001-12-09 12:38:09 sugaya>
+ *                                  Time-stamp: <04/06/21 23:36:19 sugaya>
  * ************************************************************************* */
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
 #include <gnome.h>
-#include "teoeyesplugin.h"
+#include "teoeyes_plugin.h"
 
 #define	MIN_VAL			0
 #define	MAX_VAL			255
 #define	STEP_SIZE		1
 #define	PAGE_SIZE		5
-/* ץ쥹СѤ1ѹƤ */
+/* $B%W%m%0%l%9%P!<$r;HMQ$9$k>l9g$O(B1$B$KJQ99$7$F$$2<$5$$(B */
 #define	USE_PROGRESS_BAR	0
 
 /* ************************************************************************* *
-   ץ饰ؿ
+   $B%W%i%0%$%s4X?tK\BN(B
  * ************************************************************************* */
 void
 exec_binary (GdkPixbuf	*src,
@@ -52,7 +52,7 @@ exec_binary (GdkPixbuf	*src,
 	  gdk_pixbuf_put_pixel (dst, col, row, 3, 255);
 	}
       }
-#if USE_PROGRESS_BAR /* ץ쥹СѤ1ѹƤ */
+#if USE_PROGRESS_BAR /* $B%W%m%0%l%9%P!<$r;HMQ$9$k>l9g$O(B1$B$KJQ99$7$F$$2<$5$$(B */
       plugin_progressbar_update ((double) (row - gdk_pixbuf_get_heigth (src))/
 				 (gdk_pixbuf_get_height (src)));
 #endif
@@ -64,29 +64,29 @@ exec_binary (GdkPixbuf	*src,
 }
 
 /* ************************************************************************* *
-   ץ饰¹Ѵؿ
+   $B%W%i%0%$%s<B9TMQ4X?t(B
  * ************************************************************************* */
 void
 plugin_binary (GdkPixbuf	*src,
 	       GdkPixbuf	*dst) {
-  /* ץ饰ɽ */
-  plugin_dialog_new (_("Binary Plugin"),	/* ȥ */
-		     exec_binary,		/* ץ饰ؿ */
-		     src,			/* ϲǡ */
-		     dst,			/* ϲǡ */
-		     _("Threshold"),			/* ѥ᡼٥ */
-		     MIN_VAL,			/* ѥ᡼Ǿ */
-		     MAX_VAL,			/* ѥ᡼ */
-		     STEP_SIZE,			/* ѥ᡼1 */	
-		     PAGE_SIZE,			/* ѥ᡼2 */	
-		     NON_USE_PROGRESSBAR,	/* ץ쥹Сλ */
-		     ACTION_INTERACTIVE);	/* ץӥ塼̤ιˡ */
+  /* $B%W%i%0%$%s%@%$%"%m%0$NI=<((B */
+  plugin_dialog_new (_("Binary Plugin"),	/* $B%@%$%"%m%0%?%$%H%k(B */
+		     exec_binary,		/* $B%W%i%0%$%s4X?tK\BN(B */
+		     src,			/* $BF~NO2hA|%G!<%?(B */
+		     dst,			/* $B=PNO2hA|%G!<%?(B */
+		     _("Threshold"),			/* $B%Q%i%a!<%?%i%Y%k(B */
+		     MIN_VAL,			/* $B%Q%i%a!<%?:G>.CM(B */
+		     MAX_VAL,			/* $B%Q%i%a!<%?:GBgCM(B */
+		     STEP_SIZE,			/* $B%Q%i%a!<%?A}2CNL(B1 */	
+		     PAGE_SIZE,			/* $B%Q%i%a!<%?A}2CNL(B2 */	
+		     NON_USE_PROGRESSBAR,	/* $B%W%m%0%l%9%P!<$N;HMQ(B */
+		     ACTION_INTERACTIVE);	/* $B%W%l%S%e!<2hLL$N99?7J}K!(B */
 
   gtk_main ();
 }
 
 /* ************************************************************************* *
-   ץ饰
+   $B%W%i%0%$%s>pJs(B
  * ************************************************************************* */
 PluginInfo plugin_info = {  
   {N_("/Binarize by threshold"),
