@@ -1,20 +1,18 @@
 /* ****************************************************** edge_detect.c *** *
- * Teoeyes Plugin Collection (å)
+ * Teoeyes Plugin Collection ($B%(%C%88!=P(B)
  *
- * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2001-2004 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                  Time-stamp: <2001-12-03 23:59:48 sugaya>
+ *                                  Time-stamp: <04/06/21 23:36:26 sugaya>
  * ************************************************************************* */
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
 #include <gnome.h>
-#include "teoeyesplugin.h"
+#include "teoeyes_plugin.h"
 
-#define ENABLE_NLS
-
-
-/* RGBYؿ ****************************************** */
+/* RGB$B2hA|$+$i(BY$B2hA|$r@8@.$9$k4X?t(B ****************************************** */
 static GdkPixbuf*
 _create_y_image (GdkPixbuf	*src) {
   GdkPixbuf	*dst;
@@ -39,7 +37,7 @@ _create_y_image (GdkPixbuf	*src) {
 }
 
 /* ************************************************************************* *
-   ץ饰ؿ
+   $B%W%i%0%$%s4X?tK\BN(B
  * ************************************************************************* */
 void
 plugin_edge_detect (GdkPixbuf	*src,
@@ -65,7 +63,7 @@ plugin_edge_detect (GdkPixbuf	*src,
 }
 
 /* ************************************************************************* *
-   ץ饰
+   $B%W%i%0%$%s>pJs(B
  * ************************************************************************* */
 PluginInfo plugin_info = {  
   {N_("/Edge Detection"),
