@@ -1,18 +1,19 @@
-/* ******************************************************** laplacian.c *** *
- * Teoeyes Plugin Collection (ץ饷ե륿)
+/* ********************************************************* laplacian.c *** *
+ * Teoeyes Plugin Collection ($B%i%W%i%7%"%s%U%#%k%?(B)
  *
- * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2001-2004 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                  Time-stamp: <2001-12-04 00:03:57 sugaya>
+ *                                  Time-stamp: <04/06/21 23:36:53 sugaya>
  * ************************************************************************* */
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
 #include <gnome.h>
-#include "teoeyesplugin.h"
+#include "teoeyes_plugin.h"
 
 /* ************************************************************************* *
-   ץ饰ؿ
+   $B%W%i%0%$%s4X?tK\BN(B
  * ************************************************************************* */
 void
 plugin_laplacian (GdkPixbuf	*src,
@@ -23,7 +24,7 @@ plugin_laplacian (GdkPixbuf	*src,
   int		filter[] = {-1, -1, -1, -1, 8, -1, -1, -1, -1};
   int		val[3];
 
-  /* ϲѥγ */
+  /* $B=PNO2hA|MQ%a%b%j$N3NJ](B */
   width  = gdk_pixbuf_get_width  (src);
   height = gdk_pixbuf_get_height (src);
 
@@ -52,7 +53,7 @@ plugin_laplacian (GdkPixbuf	*src,
 }
 
 /* ************************************************************************* *
-   ץ饰
+   $B%W%i%0%$%s>pJs(B
  * ************************************************************************* */
 PluginInfo plugin_info = {  
   {N_("/Laplacian Filter"),
