@@ -1,26 +1,26 @@
 /* *********************************************************** median.c *** *
- * Teoeyes Plugin Collection (ǥե륿)
+ * Teoeyes Plugin Collection ($B%a%G%#%"%s%U%#%k%?(B)
  *
- * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2001-2004 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                  Time-stamp: <2001-12-03 23:41:19 sugaya>
+ *                                  Time-stamp: <04/06/21 23:36:58 sugaya>
  * ************************************************************************* */
-#include <config.h>
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
 #include <gnome.h>
-#include "teoeyesplugin.h"
+#include "teoeyes_plugin.h"
 
 #define	MIN_VAL			1
 #define	MAX_VAL			32
 #define	STEP_SIZE		1
 #define	PAGE_SIZE		5
-/* ץ쥹СѤ1ѹƤ */
+/* $B%W%m%0%l%9%P!<$r;HMQ$9$k>l9g$O(B1$B$KJQ99$7$F$$2<$5$$(B */
 #define	USE_PROGRESS_BAR	1
 
 /* ************************************************************************* *
-   ͤ
+   $BCf4VCM$r5a$a$k(B
  * ************************************************************************* */
 guchar
 median (guchar	*val,
@@ -44,7 +44,7 @@ median (guchar	*val,
 }
 
 /* ************************************************************************* *
-   ץ饰ؿ
+   $B%W%i%0%$%s4X?tK\BN(B
  * ************************************************************************* */
 void
 exec_median (GdkPixbuf	*src,
@@ -81,13 +81,13 @@ exec_median (GdkPixbuf	*src,
 			      gdk_pixbuf_get_pixel (src, col, row, 4));
       }
     }
-#if USE_PROGRESS_BAR /* ץ쥹СѤ1ѹƤ */
+#if USE_PROGRESS_BAR /* $B%W%m%0%l%9%P!<$r;HMQ$9$k>l9g$O(B1$B$KJQ99$7$F$$2<$5$$(B */
     plugin_progressbar_update ((double) (row - scope) /
 			       (double) (gdk_pixbuf_get_height (src) 
 					 - scope + 1));
 #endif
   } 
-#if USE_PROGRESS_BAR /* ץ쥹СѤ1ѹƤ */
+#if USE_PROGRESS_BAR /* $B%W%m%0%l%9%P!<$r;HMQ$9$k>l9g$O(B1$B$KJQ99$7$F$$2<$5$$(B */
   plugin_progressbar_update (0.0);
 #endif
   for (p = 0; p < 3; p++) free (vals[p]);
@@ -95,29 +95,29 @@ exec_median (GdkPixbuf	*src,
 }
 
 /* ************************************************************************* *
-   ץ饰¹Ѵؿ
+   $B%W%i%0%$%s<B9TMQ4X?t(B
  * ************************************************************************* */
 void
 plugin_median (GdkPixbuf	*src,
 	       GdkPixbuf	*dst) {
-  /* ץ饰ɽ */
-  plugin_dialog_new (_("Median Filter"),	/* ȥ */
-		     exec_median,		/* ץ饰ؿ */
-		     src,			/* ϲǡ */
-		     dst,			/* ϲǡ */
-		     _("Scope"),		/* ѥ᡼٥ */
-		     MIN_VAL,			/* ѥ᡼Ǿ */
-		     MAX_VAL,			/* ѥ᡼ */
-		     STEP_SIZE,			/* ѥ᡼1 */	
-		     PAGE_SIZE,			/* ѥ᡼2 */	
-		     USE_PROGRESSBAR,		/* ץ쥹Сλ */
-		     ACTION_NON_INTERACTIVE);	/* ץӥ塼̤ιˡ */
+  /* $B%W%i%0%$%s%@%$%"%m%0$NI=<((B */
+  plugin_dialog_new (_("Median Filter"),	/* $B%@%$%"%m%0%?%$%H%k(B */
+		     exec_median,		/* $B%W%i%0%$%s4X?tK\BN(B */
+		     src,			/* $BF~NO2hA|%G!<%?(B */
+		     dst,			/* $B=PNO2hA|%G!<%?(B */
+		     _("Scope"),		/* $B%Q%i%a!<%?%i%Y%k(B */
+		     MIN_VAL,			/* $B%Q%i%a!<%?:G>.CM(B */
+		     MAX_VAL,			/* $B%Q%i%a!<%?:GBgCM(B */
+		     STEP_SIZE,			/* $B%Q%i%a!<%?A}2CNL(B1 */	
+		     PAGE_SIZE,			/* $B%Q%i%a!<%?A}2CNL(B2 */	
+		     USE_PROGRESSBAR,		/* $B%W%m%0%l%9%P!<$N;HMQ(B */
+		     ACTION_NON_INTERACTIVE);	/* $B%W%l%S%e!<2hLL$N99?7J}K!(B */
 
   gtk_main ();
 }
 
 /* ************************************************************************* *
-   ץ饰
+   $B%W%i%0%$%s>pJs(B
  * ************************************************************************* */
 PluginInfo plugin_info = {  
   {N_("/Median Filter"),
