@@ -1,21 +1,22 @@
 /* ****************************************************** pseudo_color.c *** *
- * Teoeyes Plugin Collection (顼)
+ * Teoeyes Plugin Collection ($B5?;w%+%i!<(B)
  *
- * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2001-2004 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                  Time-stamp: <2001-12-03 23:46:39 sugaya>
+ *                                  Time-stamp: <04/06/21 23:37:02 sugaya>
  * ************************************************************************* */
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
 #include <gnome.h>
-#include "teoeyesplugin.h"
+#include "teoeyes_plugin.h"
 
 #define	MIN_VAL			0
 #define	MAX_VAL			255
 #define	STEP_SIZE		1
 #define	PAGE_SIZE		5
-/* ץ쥹СѤ1ѹƤ */
+/* $B%W%m%0%l%9%P!<$r;HMQ$9$k>l9g$O(B1$B$KJQ99$7$F$$2<$5$$(B */
 #define	USE_PROGRESS_BAR	0
 
 /* ************************************************************************* */
@@ -56,7 +57,7 @@ gray_to_pseudo_color (guchar	src,
 }
 
 /* ************************************************************************* *
-   ץ饰¹Ѵؿ
+   $B%W%i%0%$%s<B9TMQ4X?t(B
  * ************************************************************************* */
 void
 plugin_pseudo (GdkPixbuf	*src,
@@ -82,7 +83,7 @@ plugin_pseudo (GdkPixbuf	*src,
 }
 
 /* ************************************************************************* *
-   ץ饰
+   $B%W%i%0%$%s>pJs(B
  * ************************************************************************* */
 PluginInfo plugin_info = {
   {N_("/Pseudo Color"),
