@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                    Time-stamp: <03/01/02 21:57:25 sugaya>
+ *                                    Time-stamp: <04/06/21 23:56:46 sugaya>
  * ************************************************************************* */
 #include <gdk/gdkkeysyms.h>
 #include <libgtkhtml/gtkhtml.h>
@@ -436,7 +436,7 @@ assistant_skin_new (const gchar	*skin_data) {
   /* ǡեΥץ */
   fp = fopen (skin_data, "r");
   if (!fp) {
-    g_printerr (_("Can not open assistant skin data.\n"));
+    g_printerr (_("Could not open assistant skin data.\n"));
     return NULL;
   }
   /* ǡѥγ */
