@@ -1,12 +1,14 @@
 /* ********************************************************* assistant.h *** *
- * TeoEyes - Teo Image Viewer
+ * $B%"%7%9%?%s%H$K4X$9$k4X?t(B $B%X%C%@%U%!%$%k(B
  *
- * Copyright (C) 2001 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                  Time-stamp: <2001-12-11 21:27:30 sugaya>
+ *                                    Time-stamp: <03/01/02 21:56:16 sugaya>
  * ************************************************************************* */
-#ifndef	_TE_ASSISTANT_H_
-#define	_TE_ASSISTANT_H_
+#ifndef	__ASSISTANT_H__
+#define	__ASSISTANT_H__
+
+#include "dh-html.h"
 
 /* ************************************************************************* */
 typedef struct _AssistantSkinData {
@@ -21,9 +23,11 @@ typedef struct _AssistantSkinData {
 } AssistantSkinData;
 
 /* ************************************************************************* */
-GtkWidget*	te_assistant_new	(char		*skin_data);
-
-
-#endif	/* _TE_ASSISTANT_H_ */
+GtkWidget*	assistant_new		(const char	*skin_file);
+void		assistant_destroy 	(GtkWidget	*assistant);
+GtkWidget*	html_window_new 	(void);
+void		assistant_set_document 	(DhHtml		*document,
+					 const gchar	*uri);
+#endif	/* __ASSISTANT_H__ */
 
 /* ************************************************** End of assistant.h *** */
