@@ -1,5 +1,5 @@
 /* *********************************************************** browser.c *** *
- * ץ
+ * 画像エクスプローラ
  *
  * Copyright (C) 1998-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
@@ -87,16 +87,16 @@ static GtkWidget* ixp_component_file_list_new 	(TEBrowser	*ixp);
 static gboolean	  combo_callback_flag = TRUE;
 
 /* ************************************************************************* *
- * ץ Хåؿ
+ * 画像エクスプローラ コールバック関数
  * ************************************************************************* */
 
 /* ************************************************************************* *
- * GtkWindowΥХåؿ
+ * GtkWindowのコールバック関数
  *
  * ixp_destroy
  * ************************************************************************* */
 
-/* ץΥ ******************************************** */
+/* 画像エクスプローラのクローズ ******************************************** */
 static void
 ixp_destroy (GtkWidget	*widget,
 	     gpointer	data) {
@@ -104,7 +104,7 @@ ixp_destroy (GtkWidget	*widget,
 }
 
 /* ************************************************************************* *
- * ˥塼ȥġС˶̤ΥХåؿ
+ * メニューとツールバーに共通のコールバック関数
  *
  * ixp_close
  * ixp_reload
@@ -112,7 +112,7 @@ ixp_destroy (GtkWidget	*widget,
  * ixp_switch_view_mode
  * ************************************************************************* */
 
-/* ץΥ ******************************************** */
+/* 画像エクスプローラのクローズ ******************************************** */
 static void
 ixp_close (GtkWidget	*widget,
 	   gpointer	data) {
@@ -128,7 +128,7 @@ ixp_reload (GtkWidget	*widget,
 						     (explorer->dir_tree)));
 }
 
-/* ƥݥեκ ************************************************ */
+/* テンポラリファイルの削除 ************************************************ */
 static void
 ixp_clean (GtkWidget	*widget,
 	   gpointer	data) {
@@ -146,7 +146,7 @@ ixp_clean (GtkWidget	*widget,
   g_free (msg);
 }
 
-/* ɽ⡼ɤؤ ****************************************************** */
+/* 表示モードの切替え ****************************************************** */
 static void
 ixp_switch_view_mode (GtkWidget	*widget,
 		      gpointer	data) {
@@ -169,12 +169,12 @@ ixp_switch_view_mode (GtkWidget	*widget,
 }
 
 /* ************************************************************************* *
- * ˥塼ΥХåؿ
+ * メニューのコールバック関数
  *
  * ixp_show_hidden
  * ************************************************************************* */
 
-/* ǥ쥯ȥɽ/ɽ ******************************************* */
+/* 隠しディレクトリの表示/非表示 ******************************************* */
 static void
 ixp_show_hidden (GtkWidget	*widget,
 		 gpointer	data) {
@@ -188,12 +188,12 @@ ixp_show_hidden (GtkWidget	*widget,
 }
 
 /* ************************************************************************* *
- * ġСΥХåؿ
+ * ツールバーのコールバック関数
  *
  * ixp_go_home
  * ************************************************************************* */
 
-/* ۡǥ쥯ȥذư ************************************************ */
+/* ホームディレクトリへ移動 ************************************************ */
 static void
 ixp_go_home (GtkWidget	*widget,
 	     gpointer	data) {
@@ -210,12 +210,12 @@ ixp_go_home (GtkWidget	*widget,
 }
 
 /* ************************************************************************* *
- * ǥ쥯ȥĥ꡼˴ؤ륳Хåؿ
+ * ディレクトリツリーに関するコールバック関数
  *
  * ixp_tree_select
  * ************************************************************************* */
 
-/* ǥ쥯ȥĥ꡼ǥǥ쥯ȥ꤬򤵤줿Ȥν ****************** */
+/* ディレクトリツリーでディレクトリが選択されたときの処理 ****************** */
 static gboolean
 ixp_tree_select (GtkWidget	*widget,
 		 GdkEventButton	*event,
@@ -241,7 +241,7 @@ ixp_tree_select (GtkWidget	*widget,
 }
 
 /* ************************************************************************* *
- * ܥåȤ˴ؤ륳Хåؿ
+ * コンボウィジェットに関するコールバック関数
  *
  * ixp_combo_set_dir
  * ixp_combo_changed
@@ -300,7 +300,7 @@ ixp_combo_changed (GtkWidget	*widget,
 }
 
 /* ************************************************************************* *
- * ꥹȤ˴ؤ륳Хåؿ
+ * アイコンリストに関するコールバック関数
  *
  * ixp_drag_data_get
  * ixp_select_icon
@@ -357,7 +357,7 @@ ixp_select_icon (GtkWidget	*widget,
 }
 
 /* ************************************************************************* *
- * ؿ
+ * ローカル関数
  *
  * compare_by_spell
  * ls_image
@@ -369,7 +369,7 @@ ixp_select_icon (GtkWidget	*widget,
  * ixp_file_list_add
  * ************************************************************************* */
 
-/* ̾ǥ ************************************************************ */
+/* 名前でソート ************************************************************ */
 static gint
 compare_by_spell (gconstpointer	data1,
 		  gconstpointer	data2) {
@@ -379,7 +379,7 @@ compare_by_spell (gconstpointer	data1,
   return strcmp (str1, str2);
 }
 
-/* ǥ쥯ȥβꥹȤ **************************************** */
+/* ディレクトリ内の画像リストを作成 **************************************** */
 static GList*
 ls_image (const gchar	*dir) {
   DIR		*dp;
@@ -417,7 +417,7 @@ ls_image (const gchar	*dir) {
   return files;
 }
 
-/* ͥκ **************************************************** */
+/* サムネイル画像の作成 **************************************************** */
 static gchar*
 ixp_create_icon (const gchar	*filename) {
   TEImage	*ti;
@@ -433,8 +433,8 @@ ixp_create_icon (const gchar	*filename) {
 
   while (ptr < ext) *ptr++;
   *ptr++ = '.';
+  *ptr++ = 'j';
   *ptr++ = 'p';
-  *ptr++ = 'n';
   *ptr++ = 'g';
   *ptr++ = '\0';
 
@@ -564,7 +564,7 @@ ixp_create_icon (const gchar	*filename) {
   return icon_name;
 }
 
-/* ͥɲ **************************************************** */
+/* サムネイルを一つ追加 **************************************************** */
 static void
 ixp_add_icon (GnomeImageList	*gil,
 	      const gchar	*filename,
@@ -583,7 +583,7 @@ ixp_add_icon (GnomeImageList	*gil,
   }
 }
 
-/* ͥ ************************************************ */
+/* サムネイル画像一覧の生成 ************************************************ */
 void
 ixp_scan_dir (TEBrowser		*ixp,
 	      const gchar	*dir) {
@@ -638,7 +638,7 @@ ixp_scan_dir (TEBrowser		*ixp,
   gnome_image_list_thaw (GNOME_IMAGE_LIST (ixp->iconlist));  
 }
 
-/* ܥåȤ˿ǥ쥯ȥ̾ɲ ************************** */
+/* コンボウィジェットに新しいディレクトリ名を追加 ************************** */
 void
 ixp_combo_list_add (TEBrowser	*ixp,
 		    GtkWidget	*combo,
@@ -666,7 +666,7 @@ ixp_combo_list_add (TEBrowser	*ixp,
   }
 }
 
-/* ܥåȤ˿ǥ쥯ȥ̾ɲ ************************** */
+/* コンボウィジェットに新しいディレクトリ名を追加 ************************** */
 static void
 ixp_combo_set_popdown_item (TEBrowser	*ixp,
 			    GtkCombo	*combo,
@@ -753,7 +753,7 @@ ixp_file_list_button_press (GtkWidget	*widget,
 }
 
 /* ************************************************************************* *
- * ץؿ
+ * 画像エクスプローラ生成関数
  *
  * ixp_component_menu_new
  * ixp_component_toolbar_new
@@ -762,7 +762,7 @@ ixp_file_list_button_press (GtkWidget	*widget,
  * ixp_new
  * ************************************************************************* */
 
-/* ˥塼С ****************************************************** */
+/* メニューバーの生成 ****************************************************** */
 static GtkWidget*
 ixp_component_menu_new (TEBrowser	*ixp) {
   GtkIconItemFactory	*item_factory;
@@ -772,15 +772,15 @@ ixp_component_menu_new (TEBrowser	*ixp) {
   GtkWidget		*menubar;
   gint			nmenu_items;
 
-  /* ϥɥܥå */
+  /* ハンドルボックスの生成 */
   handlebox = gtk_handle_box_new ();
   {
-    /* ե졼 */
+    /* フレームの生成 */
     frame = gtk_frame_new (NULL);
     gtk_container_add (GTK_CONTAINER (handlebox), frame);
     G_SET_WIDGET (ixp->window, "menu:frame", frame);
 
-    /* ˥塼 */
+    /* メニューの生成 */
     nmenu_items = sizeof (menu_items) / sizeof (menu_items[0]);    
     accel_group = gtk_accel_group_new ();
     item_factory
@@ -798,7 +798,7 @@ ixp_component_menu_new (TEBrowser	*ixp) {
   return handlebox;
 }
 
-/* ġС ******************************************************** */
+/* ツールバーの生成 ******************************************************** */
 static GtkWidget*
 ixp_component_toolbar_new (TEBrowser	*ixp) {
   GtkWidget	*handlebox;
@@ -806,15 +806,15 @@ ixp_component_toolbar_new (TEBrowser	*ixp) {
   GtkWidget	*icon;
   GdkPixbuf	*pixbuf;
 
-  /* ϥɥܥå */
+  /* ハンドルボックスの生成 */
   handlebox = gtk_handle_box_new ();
   {
-    /* ġС */
+    /* ツールバーの生成 */
     toolbar = gtk_toolbar_new ();
     gtk_container_add (GTK_CONTAINER (handlebox), toolbar);
     G_SET_WIDGET (ixp->window, "toolbar:toolbar", toolbar);
     {
-      /* TeoEyesεưܥ */
+      /* TeoEyesの起動ボタン */
       pixbuf = gdk_pixbuf_new_from_inline (-1, stock_new, FALSE, NULL);      
       icon = gtk_image_new_from_pixbuf (pixbuf);
       gtk_toolbar_append_element (GTK_TOOLBAR (toolbar),
@@ -829,7 +829,7 @@ ixp_component_toolbar_new (TEBrowser	*ixp) {
       G_SET_WIDGET (ixp->window, "toolbar:icon1", icon);
       gdk_pixbuf_unref (pixbuf);
 
-      /* ֳץܥ */
+      /* 「開く」ボタン */
       pixbuf = gdk_pixbuf_new_from_inline (-1, stock_open, FALSE, NULL);
       icon = gtk_image_new_from_pixbuf (pixbuf);
       gtk_toolbar_append_element (GTK_TOOLBAR (toolbar),
@@ -844,7 +844,7 @@ ixp_component_toolbar_new (TEBrowser	*ixp) {
       G_SET_WIDGET (ixp->window, "toolbar:icon2", icon);
       gdk_pixbuf_unref (pixbuf);
 #if 0
-      /* ¸ץܥ */
+      /* 「保存」ボタン */
       pixbuf = gdk_pixbuf_new_from_inline (-1, stock_save, FALSE, NULL);      
       icon = gtk_image_new_from_pixbuf (pixbuf);
       gtk_toolbar_append_element (GTK_TOOLBAR (toolbar),
@@ -856,7 +856,7 @@ ixp_component_toolbar_new (TEBrowser	*ixp) {
 				  icon,
 				  NULL,
 				  NULL);
-      /* ̾¸ץܥ */
+      /* 「別名で保存」ボタン */
       pixbuf = gdk_pixbuf_new_from_inline (-1, stock_save_as, FALSE, NULL);
       icon = gtk_image_new_from_pixbuf (pixbuf);
       gtk_toolbar_append_element (GTK_TOOLBAR (toolbar),
@@ -869,10 +869,10 @@ ixp_component_toolbar_new (TEBrowser	*ixp) {
 				  NULL,
 				  NULL);
 #endif
-      /* ѥ졼 */
+      /* セパレータ */
       gtk_toolbar_append_space (GTK_TOOLBAR (toolbar));
 
-      /* ֥饦Ĥܥ */
+      /* ブラウザを閉じるボタン */
       pixbuf = gdk_pixbuf_new_from_inline (-1, stock_close, FALSE, NULL);
       icon = gtk_image_new_from_pixbuf (pixbuf);
       gtk_widget_set_usize (icon, 48, -1);
@@ -888,7 +888,7 @@ ixp_component_toolbar_new (TEBrowser	*ixp) {
       G_SET_WIDGET (ixp->window, "toolbar:icon3", icon);
       gdk_pixbuf_unref (pixbuf);
 
-      /* ֽλץܥ */
+      /* 「終了」ボタン */
       pixbuf = gdk_pixbuf_new_from_inline (-1, stock_quit, FALSE, NULL);      
       icon = gtk_image_new_from_pixbuf (pixbuf);
       gtk_toolbar_append_element (GTK_TOOLBAR (toolbar),
@@ -903,10 +903,10 @@ ixp_component_toolbar_new (TEBrowser	*ixp) {
       G_SET_WIDGET (ixp->window, "toolbar:icon4", icon);
       gdk_pixbuf_unref (pixbuf);
 
-      /* ѥ졼 */
+      /* セパレータ */
       gtk_toolbar_append_space (GTK_TOOLBAR (toolbar));
 
-      /* ۡذưܥ */
+      /* ホームへ移動ボタン */
       pixbuf = gdk_pixbuf_new_from_inline (-1, stock_home, FALSE, NULL);
       icon = gtk_image_new_from_pixbuf (pixbuf);
       gtk_toolbar_append_element (GTK_TOOLBAR (toolbar),
@@ -921,10 +921,10 @@ ixp_component_toolbar_new (TEBrowser	*ixp) {
       G_SET_WIDGET (ixp->window, "toolbar:icon5", icon);
       gdk_pixbuf_unref (pixbuf);
 
-      /* ѥ졼 */
+      /* セパレータ */
       gtk_toolbar_append_space (GTK_TOOLBAR (toolbar));
       
-      /* ץܥ */
+      /* 「設定」ボタン */
       pixbuf = gdk_pixbuf_new_from_inline (-1, stock_prof, FALSE, NULL);
       icon = gtk_image_new_from_pixbuf (pixbuf);
       gtk_toolbar_append_element (GTK_TOOLBAR (toolbar),
@@ -939,10 +939,10 @@ ixp_component_toolbar_new (TEBrowser	*ixp) {
       G_SET_WIDGET (ixp->window, "toolbar:icon6", icon);
       gdk_pixbuf_unref (pixbuf);
 
-      /* ѥ졼 */
+      /* セパレータ */
       gtk_toolbar_append_space (GTK_TOOLBAR (toolbar));
 
-      /* ǥ쥯ȥΥ */
+      /* ディレクトリのリロード */
       pixbuf = gdk_pixbuf_new_from_inline (-1, stock_reload, FALSE, NULL);
       icon = gtk_image_new_from_pixbuf (pixbuf);
       gtk_toolbar_append_element (GTK_TOOLBAR (toolbar),
@@ -957,7 +957,7 @@ ixp_component_toolbar_new (TEBrowser	*ixp) {
       G_SET_WIDGET (ixp->window, "toolbar:icon7", icon);
       gdk_pixbuf_unref (pixbuf);
 
-      /* ֥꡼ץܥ */
+      /* 「クリーン」ボタン */
       pixbuf = gdk_pixbuf_new_from_inline (-1, stock_clean, FALSE, NULL);
       icon = gtk_image_new_from_pixbuf (pixbuf);
       gtk_toolbar_append_element (GTK_TOOLBAR (toolbar),
@@ -972,10 +972,10 @@ ixp_component_toolbar_new (TEBrowser	*ixp) {
       G_SET_WIDGET (ixp->window, "toolbar:icon8", icon);
       gdk_pixbuf_unref (pixbuf);
 
-      /* ѥ졼 */
+      /* セパレータ */
       gtk_toolbar_append_space (GTK_TOOLBAR (toolbar));
 
-      /* ɽڤؤܥ (ɽ) */
+      /* 表示切り替えボタン (アイコン表示) */
       pixbuf = gdk_pixbuf_new_from_inline (-1, stock_iconlist, FALSE, NULL);
       icon = gtk_image_new_from_pixbuf (pixbuf);
       gtk_toolbar_append_element (GTK_TOOLBAR (toolbar),
@@ -990,7 +990,7 @@ ixp_component_toolbar_new (TEBrowser	*ixp) {
       G_SET_WIDGET (ixp->window, "toolbar:icon9", icon);
       gdk_pixbuf_unref (pixbuf);
 
-      /* ɽڤؤܥ (ꥹɽ) */
+      /* 表示切り替えボタン (リスト表示) */
       pixbuf = gdk_pixbuf_new_from_inline (-1, stock_filelist, FALSE, NULL);
       icon = gtk_image_new_from_pixbuf (pixbuf);
       gtk_toolbar_append_element (GTK_TOOLBAR (toolbar),
@@ -1009,28 +1009,29 @@ ixp_component_toolbar_new (TEBrowser	*ixp) {
   return handlebox;
 }
 
-/* ܥȥ **************************************************** */
+/* コンボエントリの生成 **************************************************** */
 static GtkWidget*
 ixp_component_combo_new (TEBrowser	*ixp) {
   GtkWidget	*handlebox;
   GtkWidget	*box;
   GtkWidget	*label;
+  gchar         *label_text = _("Current Dir:");
 
-  /* ϥɥܥå */
+  /* ハンドルボックスの生成 */
   handlebox = gtk_handle_box_new ();
   gtk_container_border_width (GTK_CONTAINER (handlebox), 3);
   {
-    /* ʿBOX */
+    /* 水平BOXの生成 */
     box = gtk_hbox_new (FALSE, 0);
     gtk_container_add (GTK_CONTAINER (handlebox), box);
     G_SET_WIDGET (ixp->window, "combo:box", box);    
     {
-      /* ٥ */
-      label = gtk_label_new (_("Current Dir:"));
+      /* ラベルの生成 */
+      label = gtk_label_new (label_text);
       gtk_box_pack_start (GTK_BOX (box), label, FALSE, FALSE, 1);
       G_SET_WIDGET (ixp->window, "combo:label", label);    
 
-      /* ǥ쥯ȥꥳ */
+      /* ディレクトリコンボ */
       ixp->dir_combo = gtk_combo_new ();
       gtk_box_pack_start (GTK_BOX (box), ixp->dir_combo, TRUE, TRUE, 1);
       gtk_combo_disable_activate (GTK_COMBO (ixp->dir_combo));
@@ -1068,7 +1069,7 @@ ixp_component_file_list_new (TEBrowser	*ixp) {
 		    G_CALLBACK (ixp_file_list_button_press), ixp);
   gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);
   
-  /* ե̾ */
+  /* ファイル名 */
   renderer = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes (_("FileName"),
 						     renderer,
@@ -1079,7 +1080,7 @@ ixp_component_file_list_new (TEBrowser	*ixp) {
   gtk_tree_view_column_set_sort_column_id (column, COLUMN_FILENAME);
   gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 
-  /* ե륵 */
+  /* ファイルサイズ */
   renderer = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes (_("FileSize"),
 						     renderer,
@@ -1090,7 +1091,7 @@ ixp_component_file_list_new (TEBrowser	*ixp) {
   gtk_tree_view_column_set_sort_column_id (column, COLUMN_FILESIZE);
   gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 
-  /*  */
+  /* 画像サイズ */
   renderer = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes (_("ImageSize"),
 						     renderer,
@@ -1101,7 +1102,7 @@ ixp_component_file_list_new (TEBrowser	*ixp) {
   gtk_tree_view_column_set_sort_column_id (column, COLUMN_IMAGESIZE);
   gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
   
-  /*  */
+  /* 更新日時 */
   renderer = gtk_cell_renderer_text_new ();
   column = gtk_tree_view_column_new_with_attributes (_("UpdateTime"),
 						     renderer,
@@ -1115,7 +1116,7 @@ ixp_component_file_list_new (TEBrowser	*ixp) {
   return treeview;
 }
 
-/* ץ ************************************************ */
+/* 画像エクスプローラの生成 ************************************************ */
 TEBrowser*
 ixp_new (void) {
   TEBrowser	*ixp;
@@ -1126,14 +1127,14 @@ ixp_new (void) {
   GtkWidget	*widget;
   gchar		*folder, *ofolder, *lfolder, *lofolder, *dfolder;
 
-  /* TEBrowser¤Τΰ */ 
+  /* TEBrowser構造体の領域確保 */ 
   ixp = g_new (TEBrowser, 1);
   ixp->combo_list   = NULL;
   ixp->mode	    = BROWSER_MODE_ICON;
   ixp->sort_type    = BROWSER_SORT_BY_NAME;
   ixp->selected_dir = NULL;
   
-  /* ɥ */
+  /* ウィンドウの生成 */
   ixp->window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_wmclass (GTK_WINDOW (ixp->window),
 			  "teoeyes", "Teo Image Viewer");
@@ -1149,31 +1150,31 @@ ixp_new (void) {
   g_signal_connect (G_OBJECT (ixp->window), "delete_event",
 		    G_CALLBACK (ixp_destroy), NULL);
 
-  /* ľѥåܥå */
+  /* 垂直パックボックス */
   vbox = gtk_vbox_new (FALSE, 0);
   gtk_widget_show (vbox);
   gtk_container_add (GTK_CONTAINER (ixp->window), vbox);
   G_SET_WIDGET (ixp->window, "vbox1", vbox);
   {
-    /* ˥塼 */
+    /* メニューの生成 */
     widget = ixp_component_menu_new (ixp);
     gtk_widget_show_all (widget);
     gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, TRUE, 0);
     G_SET_WIDGET (ixp->window, "menu", widget);
 
-    /* ġС */
+    /* ツールバーの生成 */
     widget = ixp_component_toolbar_new (ixp);
     gtk_widget_show_all (widget);    
     gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 0);
     G_SET_WIDGET (ixp->window, "toolbar", widget);
 
-    /* ǥ쥯ȥꥳܤ */
+    /* ディレクトリコンボの生成 */
     widget = ixp_component_combo_new (ixp);
     gtk_widget_show_all (widget);    
     gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 0);
     G_SET_WIDGET (ixp->window, "combo", widget);
 
-    /* ѥ󥦥ɥ */
+    /* パンウィンドウの生成 */
     paned = gtk_hpaned_new ();
     gtk_widget_show (paned);
     gtk_box_pack_start (GTK_BOX (vbox), paned, TRUE, TRUE, 0);
@@ -1186,7 +1187,7 @@ ixp_new (void) {
       gtk_container_add (GTK_CONTAINER (paned), scrolled_window);
       G_SET_WIDGET (ixp->window, "scrolled_window", scrolled_window);
       {
-	/* ǥ쥯ȥĥ꡼ */
+	/* ディレクトリツリーの生成 */
 	if (tc->folder_icon) {
 	  folder   
 	    = g_build_filename (tc->folder_icon, "folder.png", NULL);
@@ -1226,7 +1227,7 @@ ixp_new (void) {
       gtk_container_add (GTK_CONTAINER (paned), widget);
       G_SET_WIDGET (ixp->window, "vbox2", widget);
       {
-	/* ꥹȤǼ륦ɥ */
+	/* アイコンリストを格納するウィンドウの生成 */
 	ixp->icon_window = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW
 					     (ixp->icon_window),
@@ -1240,7 +1241,7 @@ ixp_new (void) {
 			    ixp->icon_window, TRUE, TRUE, 0);
 	G_SET_WIDGET (ixp->window, "icon_window", ixp->icon_window);	
 	{
-	  /* ꥹȤ */
+	  /* アイコンリストの生成 */
 	  ixp->iconlist = gnome_image_list_new (tc->thumbnail_width, NULL,
 					       GNOME_IMAGE_LIST_STATIC_TEXT);
 	  g_signal_connect (G_OBJECT (ixp->iconlist), "drag_data_get",
@@ -1250,7 +1251,7 @@ ixp_new (void) {
 	  gtk_container_add (GTK_CONTAINER (ixp->icon_window), ixp->iconlist);
 	  G_SET_WIDGET (ixp->window, "iconlist", ixp->iconlist);
 	}
-	/* եꥹȤǼ륦ɥ */
+	/* ファイルリストを格納するウィンドウの生成 */
 	ixp->file_window = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW
 					     (ixp->file_window),
@@ -1264,7 +1265,7 @@ ixp_new (void) {
 			    ixp->file_window, TRUE, TRUE, 0);
 	G_SET_WIDGET (ixp->window, "file_window", ixp->file_window);
 	{
-	  /* եꥹȤ */
+	  /* ファイルリストの生成 */
 	  ixp->filelist = ixp_component_file_list_new (ixp);
 	  gtk_container_add (GTK_CONTAINER (ixp->file_window), ixp->filelist);
 	  G_SET_WIDGET (ixp->window, "filelist", ixp->filelist);
@@ -1285,7 +1286,7 @@ ixp_new (void) {
       gtk_frame_set_shadow_type (GTK_FRAME (widget), GTK_SHADOW_IN);
       G_SET_WIDGET (ixp->window, "frame", widget);
       {
-	/* ٥ */
+	/* ラベルの生成 */
 	ixp->state_label = gtk_label_new ("");
 	gtk_misc_set_alignment (GTK_MISC (ixp->state_label), 0.0, 0.5);
 	gtk_container_add (GTK_CONTAINER (widget), ixp->state_label);
