@@ -1,9 +1,9 @@
 /* ************************************************************** edit.c *** *
- * ǥåȥ
+ * $B2hA|%(%G%#%C%H%@%$%"%m%0(B
  *
  * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                    Time-stamp: <03/05/12 21:50:38 sugaya>
+ *                                    Time-stamp: <04/06/21 15:19:35 sugaya>
  * ************************************************************************* */
 #include <gdk/gdkkeysyms.h>
 #include "teoeyes.h"
@@ -129,18 +129,18 @@ static void notebook_crip_grab		(GtkWidget		*parent,
 					 GtkWidget		*notebook);
 
 /* ************************************************************************* *
- * ǥåȥɥǻѤؿ
- *    	(ɥѴؿ)
+ * $B%(%G%#%C%H%&%#%s%I%&$G;HMQ$9$k%m!<%+%k4X?t(B
+ *    	($B%&%#%s%I%&MQ4X?t(B)
  * ************************************************************************* */
 
-/* Ρȥ֥åѤΥ ******************************************** */
+/* $B%N!<%H%V%C%/MQ$N%"%$%3%s@8@.(B ******************************************** */
 static void
 icon_new (GtkWidget	*parent) {
   book_open  = gdk_pixbuf_new_from_inline (-1, stock_book_open,  FALSE, NULL);
   book_close = gdk_pixbuf_new_from_inline (-1, stock_book_close, FALSE, NULL);
 }
 
-/* Ρȥ֥åΥڡΥå **************************************** */
+/* $B%N!<%H%V%C%/$N%Z!<%82hA|$N%;%C%H(B **************************************** */
 static void
 set_page_image (GtkNotebook	*notebook,
 		gint		page_num,
@@ -157,7 +157,7 @@ set_page_image (GtkNotebook	*notebook,
   gtk_image_set_from_pixbuf (GTK_IMAGE (pixwid), pixbuf);
 }
 
-/* ڡڤؤΥڤؤ ************************************ */
+/* $B%Z!<%8@Z$jBX$(;~$N%"%$%3%s$N@Z$jBX$((B ************************************ */
 static void
 cb_page_switch (GtkWidget		*widget,
 		GtkNotebookPage 	*page,
@@ -172,7 +172,7 @@ cb_page_switch (GtkWidget		*widget,
   }
 }
 
-/* ǥåȥɥĤ ******************************************** */
+/* $B%(%G%#%C%H%&%#%s%I%&$rJD$8$k(B ******************************************** */
 static void
 cb_destroy (GtkWidget	*widget,
 	    GtkWidget	*parent) {
@@ -182,8 +182,8 @@ cb_destroy (GtkWidget	*widget,
 }
 
 /* ************************************************************************* *
- * ǥåȥɥǻѤؿ
- *    	(顼ХѥХåؿ)
+ * $B%(%G%#%C%H%&%#%s%I%&$G;HMQ$9$k%m!<%+%k4X?t(B
+ *    	($B%+%i!<%P%i%s%9MQ%3!<%k%P%C%/4X?t(B)
  * ************************************************************************* */
 static void
 color_balance_render_mod (GtkWidget		*a,
@@ -288,7 +288,7 @@ color_balance_render_mod (GtkWidget		*a,
   gdk_pixbuf_unref (scurve);
 }
 
-/* 顼㡼ȥܥι ********************************************** */
+/* $B%+%i!<%A%c!<%H%\%?%s$N99?7(B ********************************************** */
 void
 update_graphs (GtkWidget	*w) {
   GtkWidget	*a, *b;
@@ -320,7 +320,7 @@ update_graphs (GtkWidget	*w) {
   edit_draw_preview ();
 }
 
-/* 顼ͥܥ󤬲줿ν ******************************** */
+/* $B%+%i!<%A%c%s%M%k%\%?%s$,2!$5$l$?;~$N=hM}(B ******************************** */
 static void
 color_balance_channel (GtkWidget	*widget,
 		       gpointer		data) {
@@ -682,7 +682,7 @@ color_balance_button_cont (GtkWidget	*widget,
   gtk_adjustment_set_value (GTK_ADJUSTMENT (obj_cont), 256.0);
 }
 
-/* 顼Х󥹤Υդɸ᤹ͤ ************************************ */
+/* $B%+%i!<%P%i%s%9$N%0%i%U$rI8=`CM$KLa$9(B ************************************ */
 static void
 color_balance_clear (void) {
   GdkPixbufColorModifier mod;
@@ -715,7 +715,7 @@ color_balance_clear (void) {
   gtk_adjustment_set_value (GTK_ADJUSTMENT (obj_cont),   256.0);  
 }
 
-/* 顼Х󥹤ѹŬѤ ****************************************** */
+/* $B%+%i!<%P%i%s%9$NJQ99$rE,MQ$9$k(B ****************************************** */
 static void
 color_balance_button_apply (GtkWidget	*widget,
 			    gpointer	data) {
@@ -730,7 +730,7 @@ color_balance_button_apply (GtkWidget	*widget,
   color_balance_clear ();
 }
 
-/* ꥸʥ᤹ **************************************************** */
+/* $B%*%j%8%J%k2hA|$KLa$9(B **************************************************** */
 static void
 color_balance_button_reset (GtkWidget	*widget,
 			    gpointer	data) {
@@ -742,11 +742,11 @@ color_balance_button_reset (GtkWidget	*widget,
 }
 
 /* ************************************************************************* *
- * ǥåȥɥǻѤؿ
- *    	(ȥѥХåؿ)
+ * $B%(%G%#%C%H%&%#%s%I%&$G;HMQ$9$k%m!<%+%k4X?t(B
+ *    	($B%8%*%a%H%jMQ%3!<%k%P%C%/4X?t(B)
  * ************************************************************************* */
 
-/* ѹ ********************************************************** */
+/* $B2hA|$NI}$NJQ99(B ********************************************************** */
 static gboolean
 geometry_enter_width (GtkWidget		*widget,
 		      GdkEventKey	*key, 
@@ -779,7 +779,7 @@ geometry_enter_width (GtkWidget		*widget,
   return TRUE;
 }
 
-/* ι⤵ѹ ******************************************************** */
+/* $B2hA|$N9b$5$NJQ99(B ******************************************************** */
 static gboolean
 geometry_enter_height (GtkWidget	*widget,
 		       GdkEventKey	*key, 
@@ -812,14 +812,14 @@ geometry_enter_height (GtkWidget	*widget,
   return TRUE;
 }
 
-/* ڥݻ ****************************************************** */
+/* $B%"%9%Z%/%HHf$NJ];}(B ****************************************************** */
 static void
 geometry_keep_aspect (GtkWidget	*widget,
 		      gpointer	data) {
   keep_aspect = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 }
 
-/* ѹŬ **************************************************** */
+/* $B2hA|%5%$%:$NJQ99E,MQ(B **************************************************** */
 static void
 geometry_button_apply (GtkWidget	*widget,
 		       gpointer		parent) {
@@ -841,21 +841,21 @@ geometry_button_apply (GtkWidget	*widget,
   scaling_by_size (image_list, w, h);
 }
 
-/* ѹ(ϡե) ****************************************** */
+/* $B2hA|%5%$%:$NJQ99(B($B%O!<%U%5%$%:(B) ****************************************** */
 static void
 geometry_button_half (GtkWidget	*widget,
 		      gpointer	data) {
   scaling_by_scale (image_list, 0.5, 0.5);
 }
 
-/* ѹ(-10%) ************************************************** */
+/* $B2hA|%5%$%:$NJQ99(B(-10%) ************************************************** */
 static void
 geometry_button_down (GtkWidget	*widget,
 		      gpointer	data) {
   scaling_by_scale (image_list, 0.9, 0.9);
 }
 
-/* ѹ(ꥸʥ륵) ************************************** */
+/* $B2hA|%5%$%:$NJQ99(B($B%*%j%8%J%k%5%$%:(B) ************************************** */
 static void
 geometry_button_reset (GtkWidget	*widget,
 		       gpointer		parent) {
@@ -879,21 +879,21 @@ geometry_button_reset (GtkWidget	*widget,
 			     (gfloat) ti_get_height (image_list));
 }
 
-/* ѹ(+10%) ************************************************** */
+/* $B2hA|%5%$%:$NJQ99(B(+10%) ************************************************** */
 static void
 geometry_button_up (GtkWidget	*widget,
 		    gpointer	data) {
   scaling_by_scale (image_list, 1.1, 1.1);
 }
 
-/* ѹ(֥륵) ****************************************** */
+/* $B2hA|%5%$%:$NJQ99(B($B%@%V%k%5%$%:(B) ****************************************** */
 static void
 geometry_button_double (GtkWidget	*widget,
 			gpointer	data) {
   scaling_by_scale (image_list, 2.0, 2.0);
 }
 
-/*  (Ŭͤ) ******************************************* */
+/* $B2hA|$N@55,2=(B ($B:GE,CM$G@55,2=(B) ******************************************* */
 static void
 normal_button_best (GtkWidget	*widget,
 		    gpointer	data) {
@@ -904,7 +904,7 @@ normal_button_best (GtkWidget	*widget,
 	      ti_get_current_height (image_list));
 }
 
-/*  (ꤷϰϤ) ************************************* */
+/* $B2hA|$N@55,2=(B ($B;XDj$7$?HO0O$G@55,2=(B) ************************************* */
 static void
 normal_button_apply (GtkWidget	*widget,
 		     gpointer	parent) {
@@ -912,7 +912,7 @@ normal_button_apply (GtkWidget	*widget,
   GtkWidget	*widget_max;
   gdouble	min, max;
 
-  /* ͤϰ */  
+  /* $B2hAGCM$NHO0O(B */  
 #if 0
   widget_min = (GtkWidget *)
     gtk_object_get_data (GTK_OBJECT (parent), "spin_norm_min");
@@ -927,7 +927,7 @@ normal_button_apply (GtkWidget	*widget,
   max = (gdouble)
     gtk_spin_button_get_value_as_float (GTK_SPIN_BUTTON (widget_max));
   
-  /* ꤷϰϤ */
+  /* $B;XDj$7$?HO0O$G@55,2=(B */
   do_backup (image_list);  
   normalize_image (image_list, min, max);
   draw_image (image_list,
@@ -936,11 +936,11 @@ normal_button_apply (GtkWidget	*widget,
 }
 
 /* ************************************************************************* *
- * ǥåȥɥǻѤؿ
- *    	(åסѥХåؿ)
+ * $B%(%G%#%C%H%&%#%s%I%&$G;HMQ$9$k%m!<%+%k4X?t(B
+ *    	($B%/%m%C%W!u%0%i%VMQ%3!<%k%P%C%/4X?t(B)
  * ************************************************************************* */
 
-/* åΰѹ  *************************************************** */
+/* $B%/%m%C%WNN0h$NJQ99(B $B#X(B *************************************************** */
 static void
 crip_change_x (GtkWidget	*widget,
 	       gpointer		parent) {
@@ -972,7 +972,7 @@ crip_change_x (GtkWidget	*widget,
   crip_draw_area ();
 }
 
-/* åΰѹ  *************************************************** */
+/* $B%/%m%C%WNN0h$NJQ99(B $B#Y(B *************************************************** */
 static void
 crip_change_y (GtkWidget	*widget,
 	       gpointer		parent) {
@@ -1004,7 +1004,7 @@ crip_change_y (GtkWidget	*widget,
   crip_draw_area ();
 }
 
-/* åΰѹ  *************************************************** */
+/* $B%/%m%C%WNN0h$NJQ99(B $BI}(B *************************************************** */
 static void
 crip_change_width (GtkWidget	*widget,
 		   gpointer	parent) {
@@ -1036,7 +1036,7 @@ crip_change_width (GtkWidget	*widget,
   crip_draw_area ();
 }
 
-/* åΰѹ ⤵ ************************************************* */
+/* $B%/%m%C%WNN0h$NJQ99(B $B9b$5(B ************************************************* */
 static void
 crip_change_height (GtkWidget	*widget,
 		    gpointer	parent) {
@@ -1068,14 +1068,14 @@ crip_change_height (GtkWidget	*widget,
   crip_draw_area ();
 }
 
-/* åפμ¹ ********************************************************** */
+/* $B%/%m%C%W$N<B9T(B ********************************************************** */
 static void
 crip_button_apply (GtkWidget	*widget,
 		   gpointer	parent) {
   crip_do_crip ();
 }
 
-/* ֥⡼ɳ ******************************************************** */
+/* $B%0%i%V%b!<%I3+;O(B ******************************************************** */
 static void
 grab_start (GtkWidget	*widget,
 	    gpointer	parent) {
@@ -1093,7 +1093,7 @@ grab_start (GtkWidget	*widget,
 }
 
 /* ************************************************************************* *
- * ǥåȥɥΥɥؿ
+ * $B%(%G%#%C%H%&%#%s%I%&$N%&%#%s%I%&@8@.4X?t(B
  * ************************************************************************* */
 
 /* ************************************************************************* */
@@ -1133,16 +1133,16 @@ color_balance_widget_new (GtkWidget	*parent) {
   gchar		buf[256];
   gint		n;
 
-  /* ܥå */
+  /* $B%\%C%/%9$N@8@.(B */
   box = gtk_hbox_new (FALSE, 5);
   gtk_widget_show (box);
   {
-    /* ե졼 */
+    /* $B%U%l!<%`$N@8@.(B */
     frame = gtk_frame_new (NULL);
     gtk_box_pack_start (GTK_BOX (box), frame, TRUE, TRUE, 0);
     G_SET_WIDGET (parent, "frame1_cb", frame);
     {
-      /* Х */
+      /* $B%-%c%s%P%9$N@8@.(B */
       widget = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
       gtk_container_add (GTK_CONTAINER (frame), widget);
       G_SET_WIDGET (parent, "align1_cb", widget);
@@ -1154,19 +1154,19 @@ color_balance_widget_new (GtkWidget	*parent) {
 	G_SET_WIDGET (parent, "canvas", canvas);
       }
     }
-    /* ܥå */
+    /* $B%\%C%/%9$N@8@.(B */
     sbox = gtk_vbox_new (FALSE, 0);
     gtk_box_pack_start (GTK_BOX (box), sbox, FALSE, FALSE, 0);
     G_SET_WIDGET (parent, "vbox1_cb", sbox);    
     {
-      /* ʿܥå */
+      /* $B?eJ?%\%C%/%9$N@8@.(B */
       hbox = gtk_hbox_new (FALSE, 0);
       gtk_box_pack_start (GTK_BOX (sbox), hbox, FALSE, FALSE, 0);
       G_SET_WIDGET (parent, "hbox1_cb", hbox);    
       {
 	for (n = 0; n < 4; n++) {
 
-	  /* ܥ */
+	  /* $B%\%?%s$N@8@.(B */
 	  button = gtk_toggle_button_new ();
 	  g_signal_connect (G_OBJECT (button), "clicked",
 			    G_CALLBACK (color_balance_channel),
@@ -1175,13 +1175,13 @@ color_balance_widget_new (GtkWidget	*parent) {
 	  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 	  G_SET_WIDGET (parent, buf, button);
 	  {
-	    /* ե졼 */
+	    /* $B%U%l!<%`$N@8@.(B */
 	    frame = gtk_frame_new (NULL);
 	    gtk_container_border_width (GTK_CONTAINER (frame), 2);
 	    gtk_container_add (GTK_CONTAINER (button), frame);
 	    G_SET_WIDGET (parent, "frame2_cb", frame);
 	    {
-	      /* Х */
+	      /* $B%-%c%s%P%9$N@8@.(B */
 	      widget = gtk_drawing_area_new ();
 	      sprintf (buf, "draw_area%d", n);
 	      gtk_widget_set_size_request (widget, 77, 77);
@@ -1191,17 +1191,17 @@ color_balance_widget_new (GtkWidget	*parent) {
 	  }
 	}
       }
-      /* ѥ졼 */
+      /* $B%;%Q%l!<%?$N@8@.(B */
       widget = gtk_hseparator_new ();
       gtk_box_pack_start (GTK_BOX (sbox), widget, FALSE, FALSE, 5);
       G_SET_WIDGET (parent, "separator1_cb", widget);
        
-      /* ʿܥå */
+      /* $B?eJ?%\%C%/%9$N@8@.(B */
       hbox = gtk_hbox_new (FALSE, 0);
       gtk_box_pack_start (GTK_BOX (sbox), hbox, FALSE, FALSE, 0);
       G_SET_WIDGET (parent, "hbox2_cb", hbox);
       {
-	/* å */
+	/* $B%,%s%^Jd@5%&%#%8%'%C%H(B */
 	obj    = gtk_adjustment_new (256.0, 0.0, 1024.0, 1.0, 4.0, 0.0);      
 	widget = gtk_hscale_new (GTK_ADJUSTMENT (obj));
 	gtk_scale_set_digits (GTK_SCALE (widget), 0);
@@ -1218,12 +1218,12 @@ color_balance_widget_new (GtkWidget	*parent) {
 	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 	G_SET_WIDGET (parent, "button1_cb", widget);	
       }
-      /* ʿܥå */
+      /* $B?eJ?%\%C%/%9$N@8@.(B */
       hbox = gtk_hbox_new (FALSE, 0);
       gtk_box_pack_start (GTK_BOX (sbox), hbox, TRUE, TRUE, 0);
       G_SET_WIDGET (parent, "hbox3_cb", hbox);
       {
-	/* ֥饤ȥͥå */
+	/* $B%V%i%$%H%M%9Jd@5%&%#%8%'%C%H(B */
 	obj    = gtk_adjustment_new (256.0, 0.0, 1024.0, 1.0, 4.0, 0.0);
 	widget = gtk_hscale_new (GTK_ADJUSTMENT (obj));
 	gtk_scale_set_digits (GTK_SCALE (widget), 0);
@@ -1241,12 +1241,12 @@ color_balance_widget_new (GtkWidget	*parent) {
 	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 	G_SET_WIDGET (parent, "button2_cb", widget);	
       }
-      /* ʿܥå */
+      /* $B?eJ?%\%C%/%9$N@8@.(B */
       hbox = gtk_hbox_new (FALSE, 0);
       gtk_box_pack_start (GTK_BOX (sbox), hbox, TRUE, TRUE, 0);
       G_SET_WIDGET (parent, "hbox4_cb", hbox);
       {
-	/* ȥ饹å */
+	/* $B%3%s%H%i%9%HJd@5%&%#%8%'%C%H(B */
 	obj    = gtk_adjustment_new (256.0, 0.0, 1024.0, 1.0, 4.0, 0.0);
 	widget = gtk_hscale_new (GTK_ADJUSTMENT (obj));
 	gtk_scale_set_digits (GTK_SCALE (widget), 0);
@@ -1268,7 +1268,7 @@ color_balance_widget_new (GtkWidget	*parent) {
   return box;
 }
  
-/* Ρȥ֥åΥڡ1 (顼Х) **************************** */
+/* $B%N!<%H%V%C%/$N%Z!<%8(B1 ($B%+%i!<%P%i%s%9(B)$B$N@8@.(B **************************** */
 static void
 notebook_color (GtkWidget	*parent,
 		GtkWidget	*notebook) {
@@ -1279,44 +1279,44 @@ notebook_color (GtkWidget	*parent,
   GtkWidget	*hbox;
   GtkWidget	*widget;
 
-  /* ܥå */
+  /* $B%\%C%/%9$N@8@.(B */
   box = gtk_hbox_new (FALSE, 0);
   label_box = tab_label_widget_new  (_("Color Balance"), box);
   gtk_widget_show_all (label_box);
   gtk_notebook_append_page_menu(GTK_NOTEBOOK (notebook), box, label_box, NULL);
   G_SET_WIDGET (parent, "box1_2", box);    
   {
-    /* ե졼 */ 
+    /* $B%U%l!<%`$N@8@.(B */ 
     frame = gtk_frame_new (NULL); 
     gtk_container_add (GTK_CONTAINER (box), frame); 
     gtk_container_border_width (GTK_CONTAINER (frame), 2); 
     G_SET_WIDGET (parent, "frame1_2", frame);    
     {
-      /* ľܥå */
+      /* $B?bD>%\%C%/%9$N@8@.(B */
       vbox = gtk_vbox_new (FALSE, 0);
       gtk_container_add (GTK_CONTAINER (frame), vbox);
       gtk_container_set_border_width (GTK_CONTAINER (vbox), 2);      
       G_SET_WIDGET (parent, "vbox1_2", vbox);
     }
   }
-  /* ľܥåؤΥѥå */
+  /* $B?bD>%\%C%/%9$X$N%Q%C%/(B */
   {
-    /* ʿܥå */
+    /* $B?eJ?%\%C%/%9$N@8@.(B */
     widget = color_balance_widget_new (parent);
     gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 0);
     G_SET_WIDGET (parent, "cb_widget_2", widget);    
     
-    /* ѥ졼 */
+    /* $B%;%Q%l!<%?$N@8@.(B */
     widget = gtk_hseparator_new ();
     gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 3);
     G_SET_WIDGET (parent, "separator1_2", widget);    
 
-    /* ʿܥå */
+    /* $B?eJ?%\%C%/%9$N@8@.(B */
     hbox = gtk_hbox_new (FALSE, 0);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     G_SET_WIDGET (parent, "hbox1_2", hbox);    
   }
-  /* ʿܥåؤΥѥå */
+  /* $B?eJ?%\%C%/%9$X$N%Q%C%/(B */
   {
     widget =
       gtk_icon_button_new_from_inline_with_label (stock_reset_16,
@@ -1338,7 +1338,7 @@ notebook_color (GtkWidget	*parent,
   }
 }
   
-/* Ρȥ֥åΥڡ2 (ȥ) ******************************** */
+/* $B%N!<%H%V%C%/$N%Z!<%8(B2 ($B%8%*%a%H%j(B)$B$N@8@.(B ******************************** */
 static void
 notebook_geometry (GtkWidget	*parent,
 		   GtkWidget	*notebook) {
@@ -1351,7 +1351,7 @@ notebook_geometry (GtkWidget	*parent,
   GtkWidget	*widget;
   GtkObject	*obj;
 
-  /* ܥå */
+  /* $B%\%C%/%9$N@8@.(B */
   box = gtk_vbox_new (FALSE, 0);
   label_box = tab_label_widget_new  (_("Geometry"), box);
   gtk_widget_show_all (label_box);
@@ -1359,57 +1359,57 @@ notebook_geometry (GtkWidget	*parent,
   G_SET_WIDGET (parent, "box_2", box);
   G_SET_WIDGET (parent, "label_box_2", label_box);
   {
-    /* ե졼 */ 
+    /* $B%U%l!<%`$N@8@.(B */ 
     frame = gtk_frame_new (_("Size"));
     gtk_box_pack_start (GTK_BOX (box), frame, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (frame), 2);
     gtk_frame_set_label_align (GTK_FRAME (frame), 0.03, 0.5);
     G_SET_WIDGET (parent, "frame1_2", frame);
     {
-      /* ľܥå */
+      /* $B?bD>%\%C%/%9$N@8@.(B */
       vbox1 = gtk_vbox_new (FALSE, 0);
       gtk_container_add (GTK_CONTAINER (frame), vbox1);
       gtk_container_set_border_width (GTK_CONTAINER (vbox1), 2);
       G_SET_WIDGET (parent, "vbox1_2", vbox1);
     }
-    /* ѥ졼 */
+    /* $B%;%Q%l!<%?$N@8@.(B */
     widget = gtk_hseparator_new ();
     gtk_box_pack_start (GTK_BOX (box), widget, FALSE, FALSE, 5);
     G_SET_WIDGET (parent, "separator1_2", widget);    
 
-    /* ե졼 */ 
+    /* $B%U%l!<%`$N@8@.(B */ 
     frame = gtk_frame_new (_("Normalization"));
     gtk_box_pack_start (GTK_BOX (box), frame, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (frame), 2);
     gtk_frame_set_label_align (GTK_FRAME (frame), 0.03, 0.5);
     G_SET_WIDGET (parent, "frame2_2", frame);
     {
-      /* ľܥå */
+      /* $B?bD>%\%C%/%9$N@8@.(B */
       vbox2 = gtk_vbox_new (FALSE, 0);
       gtk_container_add (GTK_CONTAINER (frame), vbox2);
       gtk_container_set_border_width (GTK_CONTAINER (vbox2), 2);
       G_SET_WIDGET (parent, "vbox2_2", vbox2);
     }
   }
-  /* ľܥå1ؤΥѥå */
+  /* $B?bD>%\%C%/%9(B1$B$X$N%Q%C%-%s%0(B */
   {
-    /* ʿܥå */
+    /* $B?eJ?%\%C%/%9$N@8@.(B */
     hbox = gtk_hbox_new (FALSE, 3);
     gtk_box_pack_start (GTK_BOX (vbox1), hbox, TRUE, TRUE, 0);
     G_SET_WIDGET (parent, "hbox1_2", hbox);
     {
       gint	nw, nh;
       
-      /* ߤβĴ٤ */
+      /* $B8=:_$N2hA|%5%$%:$rD4$Y$k(B */
       nw = ti_get_width  (image_list);
       nh = ti_get_height (image_list);
 
-      /* ٥ (Width) */
+      /* $B%i%Y%k(B (Width)$B$N@8@.(B */
       widget = gtk_label_new (_("Width"));
       gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
       G_SET_WIDGET (parent, "label1_2", widget);
 
-      /* ԥܥ */
+      /* $B%9%T%s%\%?%s$N@8@.(B */
       obj = gtk_adjustment_new (nw, 1, 9999, 1, 10, 10);
       widget = gtk_spin_button_new (GTK_ADJUSTMENT (obj), 1, 0);
       gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
@@ -1419,12 +1419,12 @@ notebook_geometry (GtkWidget	*parent,
       G_SET_OBJECT (parent, "adj_size_width", obj);
       G_SET_WIDGET (parent, "spin_size_width", widget);
 
-      /* ٥ (Height) */      
+      /* $B%i%Y%k(B (Height)$B$N@8@.(B */      
       widget = gtk_label_new (_("Height"));
       gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
       G_SET_WIDGET (parent, "label2_2", widget);
 
-      /* ԥܥ */      
+      /* $B%9%T%s%\%?%s$N@8@.(B */      
       obj = gtk_adjustment_new (nh, 1, 9999, 1, 10, 10);
       widget = gtk_spin_button_new (GTK_ADJUSTMENT (obj), 1, 0);
       g_signal_connect (G_OBJECT (widget), "key_press_event",
@@ -1434,20 +1434,20 @@ notebook_geometry (GtkWidget	*parent,
       G_SET_OBJECT (parent, "adj_size_height", obj);
       G_SET_WIDGET (parent, "spin_size_height", widget);
     }
-    /* ʿܥå */
+    /* $B?eJ?%\%C%/%9$N@8@.(B */
     hbox = gtk_hbox_new (FALSE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (hbox), 2);    
     gtk_box_pack_start (GTK_BOX (vbox1), hbox, FALSE, FALSE, 0);
     G_SET_WIDGET (parent, "hbox2_2", hbox);
     {
-      /* åܥ */
+      /* $B%A%'%C%/%\%?%s$N@8@.(B */
       widget = gtk_check_button_new_with_label (_("Keep aspect"));
       g_signal_connect (G_OBJECT (widget), "toggled",
 			G_CALLBACK (geometry_keep_aspect), NULL);
       gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
       G_SET_WIDGET (parent, "check_aspect", widget);
 
-      /* ܥ */
+      /* $B%\%?%s$N@8@.(B */
       widget = gtk_button_new_from_stock (GTK_STOCK_APPLY);
       g_signal_connect (G_OBJECT (widget), "clicked",
 			G_CALLBACK (geometry_button_apply),
@@ -1456,13 +1456,13 @@ notebook_geometry (GtkWidget	*parent,
       gtk_box_pack_end (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
       G_SET_WIDGET (parent, "button1_2", widget);
     }
-    /* ʿܥ */
+    /* $B?eJ?%\%?%s$N@8@.(B */
     hbox = gtk_hbox_new (FALSE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (hbox), 2);
     gtk_box_pack_start (GTK_BOX (vbox1), hbox, FALSE, FALSE, 0);
     G_SET_WIDGET (parent, "hbox3_2", hbox);
     {
-      /* ܥ (Reset) */
+      /* $B%\%?%s$N@8@.(B (Reset) */
       widget =
 	gtk_icon_button_new_from_inline_with_label (stock_reset_16,
 						    _("Reset"),
@@ -1475,7 +1475,7 @@ notebook_geometry (GtkWidget	*parent,
       gtk_box_pack_end (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
       G_SET_WIDGET (parent, "button_size_org", widget);
 
-      /* ܥ (x 2) */
+      /* $B%\%?%s$N@8@.(B (x 2) */
       widget =
 	gtk_icon_button_new_from_inline_with_label (stock_size_double,
 						    _("x 2"),
@@ -1487,7 +1487,7 @@ notebook_geometry (GtkWidget	*parent,
       gtk_box_pack_end (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
       G_SET_WIDGET (parent, "button_size_double", widget);
 
-      /* ܥ (+10%) */
+      /* $B%\%?%s$N@8@.(B (+10%) */
       widget =
 	gtk_icon_button_new_from_inline_with_label (stock_size_up,
 						    _("+10%"),
@@ -1499,7 +1499,7 @@ notebook_geometry (GtkWidget	*parent,
       gtk_box_pack_end (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
       G_SET_WIDGET (parent, "button_size_up", widget);
 
-      /* ܥ (-10%) */
+      /* $B%\%?%s$N@8@.(B (-10%) */
       widget =
 	gtk_icon_button_new_from_inline_with_label (stock_size_down,
 						    _("-10%"),
@@ -1511,7 +1511,7 @@ notebook_geometry (GtkWidget	*parent,
       gtk_box_pack_end (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
       G_SET_WIDGET (parent, "button_size_down", widget);
 
-      /* ܥ (x 1/2)  */
+      /* $B%\%?%s$N@8@.(B (x 1/2)  */
       widget =
 	gtk_icon_button_new_from_inline_with_label (stock_size_half,
 						    _("x 1/2"),
@@ -1524,47 +1524,47 @@ notebook_geometry (GtkWidget	*parent,
       G_SET_WIDGET (parent, "button_size_half", widget);
     }    
   }
-  /* ľܥå2ؤΥѥå */
+  /* $B?bD>%\%C%/%9(B2$B$X$N%Q%C%-%s%0(B */
   {
-    /* ʿܥå */
+    /* $B?eJ?%\%C%/%9$N@8@.(B */
     hbox = gtk_hbox_new (TRUE, 0);
     gtk_box_pack_start (GTK_BOX (vbox2), hbox, TRUE, TRUE, 0);
     G_SET_WIDGET (parent, "hbox4_2", hbox);    
     {
-      /* ߤβ˹碌ϰϤ */
+      /* $B8=:_$N2hA|$K9g$o$;$F@55,2=$NHO0O$r7hDj(B */
       gdouble	min = 0, max = 255;
     
-      /* ٥ (Min Value) */
+      /* $B%i%Y%k$N@8@.(B (Min Value) */
       widget = gtk_label_new (_("Min Value"));
       gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
       G_SET_WIDGET (parent, "label3_2", widget);
 
-      /* ԥܥ */
+      /* $B%9%T%s%\%?%s$N@8@.(B */
       obj = gtk_adjustment_new (min, min, max, 1, 10, 10);
       widget = gtk_spin_button_new (GTK_ADJUSTMENT (obj), 1, 0);
       gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
       G_SET_OBJECT (parent, "adj_norm_min", obj);
       G_SET_WIDGET (parent, "spin_norm_min", widget);
 
-      /* ٥ (Max Value) */      
+      /* $B%i%Y%k$N@8@.(B (Max Value) */      
       widget = gtk_label_new (_("Max Value"));
       gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
       G_SET_WIDGET (parent, "label4_2", widget);
 
-      /* ԥܥ */      
+      /* $B%9%T%s%\%?%s$N@8@.(B */      
       obj = gtk_adjustment_new (max, min, max, 1, 10, 10);
       widget = gtk_spin_button_new (GTK_ADJUSTMENT (obj), 1, 0);
       gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
       G_SET_OBJECT (parent, "adj_norm_max", obj);
       G_SET_WIDGET (parent, "spin_norm_max", widget);
     }
-    /* ʿܥå */
+    /* $B?eJ?%\%C%/%9$N@8@.(B */
     hbox = gtk_hbox_new (FALSE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (hbox), 2);
     gtk_box_pack_start (GTK_BOX (vbox2), hbox, FALSE, TRUE, 0);
     G_SET_WIDGET (parent, "hbox5_2", hbox);    
     {
-      /* ܥ (Apply) */            
+      /* $B%\%?%s$N@8@.(B (Apply) */            
       widget = gtk_button_new_from_stock (GTK_STOCK_APPLY);
       g_signal_connect (G_OBJECT (widget), "clicked",
 			G_CALLBACK (normal_button_apply), parent);
@@ -1572,7 +1572,7 @@ notebook_geometry (GtkWidget	*parent,
       gtk_box_pack_end (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
       G_SET_WIDGET (parent, "button2_2", widget);    
 
-      /* ܥ (Best) */
+      /* $B%\%?%s$N@8@.(B (Best) */
       widget =
 	gtk_icon_button_new_from_inline_with_label (stock_level,
 						    _("Best"), 
@@ -1587,7 +1587,7 @@ notebook_geometry (GtkWidget	*parent,
   }
 }
 
-/* Ρȥ֥åΥڡ3 (å&) *************************** */
+/* $B%N!<%H%V%C%/$N%Z!<%8(B3 ($B%/%m%C%W(B&$B%0%i%V(B)$B$N@8@.(B *************************** */
 static void
 notebook_crip_grab (GtkWidget	*parent,
 		    GtkWidget	*notebook) {
@@ -1600,7 +1600,7 @@ notebook_crip_grab (GtkWidget	*parent,
   GtkWidget	*widget;
   GtkObject	*obj;
   
-  /* ܥå */
+  /* $B%\%C%/%9$N@8@.(B */
   box = gtk_vbox_new (FALSE, 0);
   label_box = tab_label_widget_new  (_("Cripping & Grab"), box);
   gtk_widget_show_all (label_box);
@@ -1608,57 +1608,57 @@ notebook_crip_grab (GtkWidget	*parent,
   G_SET_WIDGET (parent, "box_3", box);
   G_SET_WIDGET (parent, "label_box_3", label_box);
   {
-    /* ե졼 */ 
+    /* $B%U%l!<%`$N@8@.(B */ 
     frame = gtk_frame_new (_("Cripping"));
     gtk_box_pack_start (GTK_BOX (box), frame, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (frame), 2);
     gtk_frame_set_label_align (GTK_FRAME (frame), 0.03, 0.5);
     G_SET_WIDGET (parent, "frame_3", frame);
     {
-      /* ľܥå */
+      /* $B?bD>%\%C%/%9(B */
       vbox1 = gtk_vbox_new (FALSE, 0);
       gtk_container_add (GTK_CONTAINER (frame), vbox1);
       gtk_container_set_border_width (GTK_CONTAINER (vbox1), 2);
       G_SET_WIDGET (parent, "vbox1_3", vbox1);
     }
-    /* ѥ졼 */
+    /* $B%;%Q%l!<%?$N@8@.(B */
     widget = gtk_hseparator_new ();
     gtk_box_pack_start (GTK_BOX (box), widget, FALSE, FALSE, 5);
     G_SET_WIDGET (parent, "separator_3", widget);
     
-    /* ե졼 */ 
+    /* $B%U%l!<%`$N@8@.(B */ 
     frame = gtk_frame_new (_("Grab"));
     gtk_box_pack_start (GTK_BOX (box), frame, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (frame), 2);
     gtk_frame_set_label_align (GTK_FRAME (frame), 0.03, 0.5);
     G_SET_WIDGET (parent, "frame2_3", frame);
     {
-      /* ľܥå */
+      /* $B?bD>%\%C%/%9(B */
       vbox2 = gtk_vbox_new (FALSE, 0);
       gtk_container_add (GTK_CONTAINER (frame), vbox2);
       gtk_container_set_border_width (GTK_CONTAINER (vbox2), 2);
       G_SET_WIDGET (parent, "vbox2_3", vbox2);
     }
   }
-  /* ľܥå1ؤΥѥå */
+  /* $B?bD>%\%C%/%9(B1$B$X$N%Q%C%-%s%0(B */
   {
-    /* ʿܥå */
+    /* $B?eJ?%\%C%/%9$N@8@.(B */
     hbox = gtk_hbox_new (TRUE, 0);
     gtk_box_pack_start (GTK_BOX (vbox1), hbox, TRUE, TRUE, 0);
     G_SET_WIDGET (parent, "hbox1_3", hbox);
     {
       gint	w, h;
       
-      /* γ */
+      /* $B2hA|%5%$%:$N3MF@(B */
       w = ti_get_width  (image_list);
       h = ti_get_height (image_list);
       
-      /* ٥ X */
+      /* $B%i%Y%k$N@8@.(B X */
       widget = gtk_label_new (_("X"));
       gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
       G_SET_WIDGET (parent, "label1_3", widget);
 
-      /* ԥܥ */
+      /* $B%9%T%s%\%?%s$N@8@.(B */
       obj = gtk_adjustment_new (0, 0, w, 1, 10, 10);
       widget = gtk_spin_button_new (GTK_ADJUSTMENT (obj), 1, 0);
       g_signal_connect (G_OBJECT (obj), "value_changed",
@@ -1667,12 +1667,12 @@ notebook_crip_grab (GtkWidget	*parent,
       G_SET_OBJECT (parent, "adj_crip_x", obj);
       G_SET_WIDGET (parent, "spin_crip_x", widget);
 
-      /* ٥ Y */      
+      /* $B%i%Y%k$N@8@.(B Y */      
       widget = gtk_label_new (_("Y"));
       gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
       G_SET_WIDGET (parent, "label2_3", widget);
 
-      /* ԥܥ */
+      /* $B%9%T%s%\%?%s$N@8@.(B */
       obj = gtk_adjustment_new (0, 0, h, 1, 10, 10);
       widget = gtk_spin_button_new (GTK_ADJUSTMENT (obj), 1, 0);
       g_signal_connect (G_OBJECT (obj), "value_changed",
@@ -1681,23 +1681,23 @@ notebook_crip_grab (GtkWidget	*parent,
       G_SET_OBJECT (parent, "adj_crip_y", obj);
       G_SET_WIDGET (parent, "spin_crip_y", widget);
     }
-    /* ʿܥå */
+    /* $B?eJ?%\%C%/%9$N@8@.(B */
     hbox = gtk_hbox_new (TRUE, 0);
     gtk_box_pack_start (GTK_BOX (vbox1), hbox, TRUE, TRUE, 0);
     G_SET_WIDGET (parent, "hbox2_3", hbox);
     {
       gint	w, h;
       
-      /* γ */
+      /* $B2hA|%5%$%:$N3MF@(B */
       w = ti_get_width  (image_list);
       h = ti_get_height (image_list);
 
-      /* ٥ Width */            
+      /* $B%i%Y%k$N@8@.(B Width */            
       widget = gtk_label_new (_("Width"));
       gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
       G_SET_WIDGET (parent, "label3_3", widget);
       
-      /* ԥܥ */
+      /* $B%9%T%s%\%?%s$N@8@.(B */
       obj = gtk_adjustment_new (0, 0, w, 1, 10, 10);
       widget = gtk_spin_button_new (GTK_ADJUSTMENT (obj), 1, 0);
       g_signal_connect (G_OBJECT (obj), "value_changed",
@@ -1707,12 +1707,12 @@ notebook_crip_grab (GtkWidget	*parent,
       G_SET_OBJECT (parent, "adj_crip_width", obj);
       G_SET_WIDGET (parent, "spin_crip_width", widget);
 
-      /* ٥ Height */                  
+      /* $B%i%Y%k$N@8@.(B Height */                  
       widget = gtk_label_new (_("Height"));
       gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
       G_SET_WIDGET (parent, "label4_3", widget);
 
-      /* ԥܥ */
+      /* $B%9%T%s%\%?%s$N@8@.(B */
       obj = gtk_adjustment_new (0, 0, h, 1, 10, 10);
       widget = gtk_spin_button_new (GTK_ADJUSTMENT (obj), 1, 0);
       g_signal_connect (G_OBJECT (obj), "value_changed",
@@ -1722,13 +1722,13 @@ notebook_crip_grab (GtkWidget	*parent,
       G_SET_OBJECT (parent, "adj_crip_height", obj);
       G_SET_WIDGET (parent, "spin_crip_height", widget);
     }
-    /* ʿܥå */
+    /* $B?eJ?%\%C%/%9$N@8@.(B */
     hbox = gtk_hbox_new (FALSE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (hbox), 2);        
     gtk_box_pack_start (GTK_BOX (vbox1), hbox, FALSE, FALSE, 0);
     G_SET_WIDGET (parent, "hbox3_3", hbox);
     {
-      /* ܥ Apply */
+      /* $B%\%?%s(B Apply */
       widget = gtk_button_new_from_stock (GTK_STOCK_APPLY);
       g_signal_connect (G_OBJECT (widget), "clicked",
 			G_CALLBACK (crip_button_apply),
@@ -1738,9 +1738,9 @@ notebook_crip_grab (GtkWidget	*parent,
       G_SET_WIDGET (parent, "button1_3", widget);
     }
   }
-  /* ľܥå2ؤΥѥå */
+  /* $B?bD>%\%C%/%9(B2$B$X$N%Q%C%-%s%0(B */
   {
-    /* ٥ */
+    /* $B%i%Y%k$N@8@.(B */
     widget = gtk_label_new (_("Left button grabs a rectanguler area,\n"
 			      "Middle butotn grabs a window,\n"
 			      "Right button cancels."));
@@ -1748,7 +1748,7 @@ notebook_crip_grab (GtkWidget	*parent,
     gtk_label_set_line_wrap (GTK_LABEL (widget), TRUE);
     G_SET_WIDGET (parent, "label5_3", widget);
 
-    /* ʿܥå */
+    /* $B?eJ?%\%C%/%9$N@8@.(B */
     hbox = gtk_hbox_new (FALSE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (hbox), 2);    
     gtk_box_pack_end (GTK_BOX (vbox2), hbox, FALSE, FALSE, 0);
@@ -1772,7 +1772,7 @@ notebook_crip_grab (GtkWidget	*parent,
   }
 }
 
-/* ǥåȥ ********************************************** */
+/* $B%(%G%#%C%H%@%$%"%m%0$N@8@.(B ********************************************** */
 GtkWidget*
 edit_window_new (void) {
   GtkWidget	*window;
@@ -1782,7 +1782,7 @@ edit_window_new (void) {
   GtkWidget	*hbox;
   GtkWidget	*widget;
 
-  /* ɥ */
+  /* $B%&%#%s%I%&$N@8@.(B */
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_wmclass  (GTK_WINDOW (window), "teoeyes", "Teo Image Viewer");
   gtk_window_set_title    (GTK_WINDOW (window), _("Teoeyes Image Editor"));
@@ -1793,20 +1793,20 @@ edit_window_new (void) {
   g_signal_connect (G_OBJECT (window),
 		    "delete_event", G_CALLBACK (cb_destroy), NULL);
 
-  /* ե졼 */
+  /* $B%U%l!<%`$N@8@.(B */
   widget = gtk_frame_new (NULL);
   gtk_container_set_border_width (GTK_CONTAINER (widget), 2);
   gtk_container_add (GTK_CONTAINER (window), widget);
   G_SET_WIDGET (window, "frame", widget);
   {
-    /* ľܥå */
+    /* $B?bD>%\%C%/%9$N@8@.(B */
     vbox = gtk_vbox_new (FALSE, 0);
     gtk_container_add (GTK_CONTAINER (widget), vbox);
     G_SET_WIDGET (window, "vbox", vbox);
   }
-  /* ʿܥåؤΥѥå */
+  /* $B?eJ?%\%C%/%9$X$N%Q%C%-%s%0(B */
   {
-    /* Ρȥ֥å */
+    /* $B%N!<%H%V%C%/$N@8@.(B */
     notebook = gtk_notebook_new ();
     g_signal_connect (G_OBJECT (notebook),
 		      "switch_page", G_CALLBACK (cb_page_switch), NULL);
@@ -1820,12 +1820,12 @@ edit_window_new (void) {
       notebook_geometry (window, notebook);
       notebook_crip_grab(window, notebook);
     }
-    /* ѥ졼 */
+    /* $B%;%Q%l!<%?$N@8@.(B */
     widget = gtk_hseparator_new ();
     gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, TRUE, 5);
     G_SET_WIDGET (window, "separator", widget);
 
-    /* ʿܥå */
+    /* $B?eJ?%\%C%/%9$N@8@.(B */
     hbox = gtk_hbox_new (FALSE, 0);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), 2);      
@@ -1852,8 +1852,8 @@ edit_draw_preview (void) {
   GdkPixbuf	*back, *pbuf;
   GdkPixmap	*pixmap;
   GdkBitmap	*mask;
-  static gint	pw = 160;	/* ץӥ塼κ */
-  static gint	ph = 120;	/* ץӥ塼κ⤵ */
+  static gint	pw = 160;	/* $B%W%l%S%e!<2hA|$N:GBgI}(B */
+  static gint	ph = 120;	/* $B%W%l%S%e!<2hA|$N:GBg9b$5(B */
   gint		w, h;
   
   canvas = get_widget (edit_window, "canvas");
@@ -1881,10 +1881,10 @@ edit_draw_preview (void) {
   gdk_pixbuf_composite_color (pbuf, back, 0, 0, w, h, 0, 0, 1.0, 1.0,
 			      GDK_INTERP_TILES,
 			      255, 0, 0, 8, 0xaaaaaa, 0x555555);
-  /* ԥåޥåפ */
+  /* $B%T%C%/%9%^%C%W$N@8@.(B */
   gdk_pixbuf_render_pixmap_and_mask (back, &pixmap, &mask, 255);
 
-  /* ɥؤ */
+  /* $B%&%#%s%I%&$X$NIA2h(B */
   gdk_window_set_back_pixmap (window, pixmap, FALSE);
   gdk_window_clear (window);
   gdk_window_shape_combine_mask (window, mask, 0, 0);
