@@ -3,7 +3,7 @@
  *
  * Copyright (C) 1998-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                    Time-stamp: <03/04/28 22:08:44 sugaya>
+ *                                    Time-stamp: <04/06/22 01:02:42 sugaya>
  * ************************************************************************* */
 #include <ctype.h>
 #include "teoeyes.h"
@@ -165,7 +165,7 @@ getargs (int		argc,		/* ο */
   if (!image_list) {
     /* ¸ߤ뤫Ĵ٤ */
     if (!g_file_exist ((*tc)->title_image)) {
-      g_printerr ("%s %s\n", _("Can not find file :"), (*tc)->title_image);
+      g_printerr ("%s %s\n", _("Could not find file :"), (*tc)->title_image);
       exit (1);
     }
     /*  */
@@ -173,7 +173,7 @@ getargs (int		argc,		/* ο */
     if (!tmpimg) exit (1);
     image_list = g_list_append (image_list, (gpointer) tmpimg);
     if (!image_list) {
-      g_printerr (_("Can not allocate enough memory.\n"));
+      g_printerr (_("Could not allocate enough memory.\n"));
       exit (1);
     }
   }
