@@ -1,15 +1,15 @@
 /* ************************************************************** grab.h *** *
- * TeoEyes - Teo Image Viewer
+ * Υ إåե
  *
- * Copyright (C) 2001 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                  Time-stamp: <2001-11-09 11:38:47 sugaya>
+ *                                  Time-stamp: <03/05/02 23:16:59 sugaya>
  * ************************************************************************* */
-#ifndef	_TE_GRAB_H_
-#define	_TE_GRAB_H_
+#ifndef	__GRAB_H__
+#define	__GRAB_H__
 
-void	te_grab_do		(void);
+void	grab_do_grab		(void);
 
-#endif	/* _TE_GRAB_H_ */
+#endif	/* __GRAB_H__ */
 
 /* ******************************************************* End of grab.h *** */
