@@ -1,9 +1,9 @@
 /* ********************************************** gtkcustomiconfilesel.c *** *
- * ޥǽʥե
+ * $B%+%9%?%^%$%:2DG=$J%U%!%$%kA*Br%@%$%"%m%0(B
  *
  * Copyright (C) 2000-2002 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                    Time-stamp: <03/05/14 23:37:01 sugaya>
+ *                                    Time-stamp: <04/06/22 01:59:34 sugaya>
  *
  * gtkiconfileselection - gtkiconfileselection dialog widget for gtk+
  * Copyright 1999  Adrian E. Feiguin <feiguin@ifir.edu.ar>
@@ -325,17 +325,16 @@ gtk_custom_icon_file_selection_init (GtkCustomIconFileSel	*filesel) {
   gchar		*folder, *ofolder, *lfolder, *lofolder, *dfolder;
 
   filesel->show_tree = TRUE;
-  
   gtk_window_set_policy (GTK_WINDOW (filesel), FALSE, TRUE, TRUE);
   gtk_container_set_border_width (GTK_CONTAINER (filesel), 10);
-
-  /* ʿܥåɲ */
+  
+  /* $B?eJ?%\%C%/%9$NDI2C(B */
   main_hbox = gtk_hbox_new (FALSE, 1);
   gtk_widget_ref (main_hbox);
   gtk_container_add (GTK_CONTAINER (filesel), main_hbox);
   gtk_widget_show (main_hbox);
 
-  /* ܥå0ɲ */
+  /* $B%+%9%?%`%\%C%/%9(B0$B$NDI2C(B */
   filesel->custom_box[0] = gtk_vbox_new (FALSE, 0);
   gtk_widget_ref (filesel->custom_box[0]);  
   gtk_box_pack_start (GTK_BOX (main_hbox),
@@ -347,26 +346,26 @@ gtk_custom_icon_file_selection_init (GtkCustomIconFileSel	*filesel) {
   gtk_box_pack_start (GTK_BOX (main_hbox), main_vbox, TRUE, TRUE, 0);
   gtk_widget_show (main_vbox);
 
-  /* ܥå1ɲ */
+  /* $B%+%9%?%`%\%C%/%9(B1$B$NDI2C(B */
   filesel->custom_box[1] = gtk_vbox_new (FALSE, 0);
   gtk_widget_ref (filesel->custom_box[1]);
   gtk_box_pack_start (GTK_BOX (main_hbox),
 		      filesel->custom_box[1], FALSE, FALSE, 0);
 
-  /* ܥå2ɲ */
+  /* $B%+%9%?%`%\%C%/%9(B2$B$NDI2C(B */
   filesel->custom_box[2] = gtk_hbox_new (FALSE, 0);
   gtk_widget_ref (filesel->custom_box[2]);    
   gtk_box_pack_start (GTK_BOX (main_vbox),
 		      filesel->custom_box[2], FALSE, FALSE, 0);
 
-  /* ǥ쥯ȥꥨȥ, եܥɲ */
+  /* $B%G%#%l%/%H%j%(%s%H%j(B, $B%U%)%k%@%\%?%s$NDI2C(B */
   filesel->custom_box[3] = gtk_hbox_new (FALSE, 1);
   gtk_widget_ref (filesel->custom_box[3]);    
   gtk_box_pack_start (GTK_BOX (main_vbox),
 		      filesel->custom_box[3], FALSE, FALSE, 5);
   gtk_widget_show (filesel->custom_box[3]);
   {
-    /* ٥ */
+    /* $B%i%Y%k(B */
     label = gtk_label_new (_("Current Folder:"));
     gtk_widget_ref (label);
     gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
@@ -374,7 +373,7 @@ gtk_custom_icon_file_selection_init (GtkCustomIconFileSel	*filesel) {
 			label, FALSE, FALSE, 0);
     gtk_widget_show (label);
 
-    /* ǥ쥯ȥꥳ */
+    /* $B%G%#%l%/%H%j%3%s%\(B */
     filesel->dir_combo = gtk_combo_new ();
     gtk_widget_ref (filesel->dir_combo);
     gtk_box_pack_start (GTK_BOX (filesel->custom_box[3]),
@@ -389,10 +388,10 @@ gtk_custom_icon_file_selection_init (GtkCustomIconFileSel	*filesel) {
 		      (gpointer) filesel);
     gtk_widget_show (GTK_COMBO (filesel->dir_combo)->entry);
 
-    /* ġåפ */
+    /* $B%D!<%k%A%C%W$N@8@.(B */
     tooltips = gtk_tooltips_new ();
 
-    /* [ƥǥ쥯ȥ]ܥ */
+    /* [$B?F%G%#%l%/%H%j$X(B]$B%\%?%s(B */
     filesel->folder_button_up
       = gtk_icon_button_new_from_inline (folder_up_pixbuf);
     gtk_widget_ref (filesel->folder_button_up);    
@@ -405,7 +404,7 @@ gtk_custom_icon_file_selection_init (GtkCustomIconFileSel	*filesel) {
     gtk_tooltips_set_tip (tooltips, filesel->folder_button_up,
 			  _("Go to parent folder"), NULL);
 
-    /* [ǥ쥯ȥκ]ܥ */    
+    /* [$B%G%#%l%/%H%j$N:n@.(B]$B%\%?%s(B */    
     filesel->folder_button_new
       = gtk_icon_button_new_from_inline (folder_new_pixbuf);
     gtk_widget_ref (filesel->folder_button_new);    
@@ -418,7 +417,7 @@ gtk_custom_icon_file_selection_init (GtkCustomIconFileSel	*filesel) {
     gtk_tooltips_set_tip (tooltips, filesel->folder_button_new,
 			  _("Create new folder"), NULL);
 
-    /* [ۡǥ쥯ȥ]ܥ */    
+    /* [$B%[!<%`%G%#%l%/%H%j$X(B]$B%\%?%s(B */    
     filesel->folder_button_home
       = gtk_icon_button_new_from_inline (home_pixbuf);
     gtk_widget_ref (filesel->folder_button_home);    
@@ -431,26 +430,26 @@ gtk_custom_icon_file_selection_init (GtkCustomIconFileSel	*filesel) {
     gtk_tooltips_set_tip (tooltips, filesel->folder_button_home,
 			  _("Go to home folder"), NULL);
   }
-  /* ܥå4ɲ */
+  /* $B%+%9%?%`%\%C%/%9$N(B4$BDI2C(B */
   filesel->custom_box[4] = gtk_hbox_new (FALSE, 0);
   gtk_widget_ref (filesel->custom_box[4]);
   gtk_box_pack_start (GTK_BOX (main_vbox),
 		      filesel->custom_box[4], FALSE, FALSE, 0);
 
-  /* ܥå4ɲ */
+  /* $B%+%9%?%`%\%C%/%9$N(B4$BDI2C(B */
   filesel->custom_box[5] = gtk_hbox_new (FALSE, 0);
   gtk_widget_ref (filesel->custom_box[5]);
   gtk_box_pack_start (GTK_BOX (main_vbox),
 		      filesel->custom_box[5], FALSE, FALSE, 0);
   gtk_widget_show (filesel->custom_box[5]);
   
-  /* ʿڥ */
+  /* $B?eJ?$Z%$%s$N@8@.(B */
   hpaned = gtk_hpaned_new ();
   gtk_widget_ref (hpaned);
   gtk_widget_show (hpaned);
   gtk_box_pack_start (GTK_BOX (filesel->custom_box[5]),hpaned,FALSE, FALSE, 0);
   
-  /* ե졼ɲ */
+  /* $B%U%l!<%`$NDI2C(B */
   frame = gtk_frame_new (NULL);
   gtk_widget_ref (frame);
   if (filesel->show_tree) gtk_widget_show (frame);
@@ -496,7 +495,7 @@ gtk_custom_icon_file_selection_init (GtkCustomIconFileSel	*filesel) {
 		    G_CALLBACK (cb_treeview_button_release),
 		    (gpointer) filesel);
 
-  /* ե졼ɲ */
+  /* $B%U%l!<%`$NDI2C(B */
   frame = gtk_frame_new (NULL);
   gtk_widget_ref (frame);
   gtk_widget_show (frame);
@@ -534,13 +533,13 @@ gtk_custom_icon_file_selection_init (GtkCustomIconFileSel	*filesel) {
   g_signal_connect (G_OBJECT (filesel->file_list), "select_icon",
 		    G_CALLBACK (cb_filelist_select_icon), (gpointer) filesel);
 
-  /* ѥ졼ɲ */
+  /* $B%;%Q%l!<%?$NDI2C(B */
   separator = gtk_hseparator_new ();
   gtk_widget_ref (separator);
   gtk_widget_show (separator);
   gtk_box_pack_start(GTK_BOX(main_vbox), separator, FALSE, FALSE, 5);  
 
-  /* ܥå6ɲ */
+  /* $B%+%9%?%`%\%C%/%9$N(B6$BDI2C(B */
   filesel->custom_box[6] = gtk_hbox_new (FALSE, 0);
   gtk_widget_ref (filesel->custom_box[6]);
   gtk_box_pack_start (GTK_BOX (main_vbox),
@@ -596,14 +595,16 @@ gtk_custom_icon_file_selection_init (GtkCustomIconFileSel	*filesel) {
   gtk_box_pack_start (GTK_BOX (box), filesel->cancel_button, TRUE, TRUE, 0);
   gtk_widget_show(filesel->cancel_button);
 
-  /* ܥå4ɲ */
+  /* $B%+%9%?%`%\%C%/%9$N(B4$BDI2C(B */
   filesel->custom_box[7] = gtk_hbox_new (FALSE, 0);
   gtk_widget_ref (filesel->custom_box[7]);
   gtk_box_pack_start (GTK_BOX (main_vbox),
 		      filesel->custom_box[7], FALSE, FALSE, 0);
 
   getcwd (dir, sizeof (dir));
+#if 1
   gtk_custom_icon_file_selection_set_dir (filesel, dir);
+#endif
 }
 
 /* ************************************************************************* *
@@ -723,7 +724,7 @@ cb_filelist_select_icon (GnomeFileIconList	*iconlist,
 }
 
 /* ************************************************************************* *
- * ǥ쥯ȥĥ꡼Хåؿ
+ * $B%G%#%l%/%H%j%D%j!<%3!<%k%P%C%/4X?t(B
  *
  * cb_treeview_button_release
  *
@@ -761,7 +762,7 @@ cb_treeview_button_release (GtkWidget		*widget,
 }
 
 /* ************************************************************************* *
- * դܤ˴ؤؿ
+ * $B$U$)$k$@$\$?$s$K4X$9$k4X?t(B
  *
  * cb_folder_up
  * cb_folder_new
@@ -769,7 +770,7 @@ cb_treeview_button_release (GtkWidget		*widget,
  *
  * ************************************************************************* */
 
-/* ֿƥǥ쥯ȥذưץܥ򲡤Ȥν ************************ */
+/* $B!V?F%G%#%l%/%H%j$X0\F0!W%\%?%s$r2!$7$?$H$-$N=hM}(B ************************ */
 static void
 cb_folder_up (GtkWidget	*widget,
 	      gpointer	data) {
@@ -800,7 +801,7 @@ cb_folder_up (GtkWidget	*widget,
   g_free (utf8_path);
 }
 
-/* ֿǥ쥯ȥץܥ򲡤Ȥν ************************ */
+/* $B!V?75,%G%#%l%/%H%j:n@.!W%\%?%s$r2!$7$?$H$-$N=hM}(B ************************ */
 static void
 cb_folder_new (GtkWidget	*widget,
 	       gpointer	data) {
@@ -812,7 +813,7 @@ cb_folder_new (GtkWidget	*widget,
   gtk_window_set_transient_for (GTK_WINDOW (window), GTK_WINDOW (data));
 }
 
-/* ֥ۡذưץܥ򲡤Ȥν ******************************** */
+/* $B!V%[!<%`$X0\F0!W%\%?%s$r2!$7$?$H$-$N=hM}(B ******************************** */
 static void
 cb_folder_home (GtkWidget	*widget,
 		gpointer	data) {
@@ -834,7 +835,7 @@ cb_folder_home (GtkWidget	*widget,
 }
 
 /* ************************************************************************* *
- * ǥ쥯ȥɥ˴ؤؿ
+ * $B?75,%G%#%l%/%H%j:n@.%&%#%s%I%&$K4X$9$k4X?t(B
  *
  * mkdir_window_new
  * cb_mkdir_button_ok
@@ -843,7 +844,7 @@ cb_folder_home (GtkWidget	*widget,
  * 
  * ************************************************************************* */
 
-/* ǥ쥯ȥɥ ************************************ */
+/* $B?75,%G%#%l%/%H%j:n@.%&%#%s%I%&$N@8@.(B ************************************ */
 static GtkWidget*
 mkdir_window_new (GtkCustomIconFileSel	*parent) {
   GtkWidget *window;
@@ -918,7 +919,7 @@ mkdir_window_new (GtkCustomIconFileSel	*parent) {
   return window;
 }
 
-/* OKܥ򲡤Ȥν ********************************************** */
+/* OK$B%\%?%s$r2!$7$?$H$-$N=hM}(B ********************************************** */
 static void
 cb_mkdir_button_ok (GtkWidget	*widget,
 		    gpointer	data) {
@@ -949,7 +950,7 @@ cb_mkdir_button_ok (GtkWidget	*widget,
 			 G_CONVERT_ERROR, G_CONVERT_ERROR_ILLEGAL_SEQUENCE)) {
       buf = g_strdup_printf (_("The folder name \"%s\" contains symbols that are not allowed in filenames"), text);
     } else {
-      buf = g_strdup_printf (_("Error creating folder \"%s\": %s\n%s"), 
+      buf = g_strdup_printf (_("Error creating folder \"%s\": %s\n%s\n"), 
 			     text, error->message,
 			     _("You probably used symbols not allowed in filenames."));
       g_printerr ("%s", buf);
@@ -968,7 +969,7 @@ cb_mkdir_button_ok (GtkWidget	*widget,
   gtk_widget_destroy (window);
 }
 
-/* 󥻥ܥ򲡤Ȥν ************************************** */
+/* $B%-%c%s%;%k%\%?%s$r2!$7$?$H$-$N=hM}(B ************************************** */
 static void
 cb_mkdir_button_cancel (GtkWidget	*widget,
 			gpointer	data) {
@@ -977,7 +978,7 @@ cb_mkdir_button_cancel (GtkWidget	*widget,
 }
 
 /* ************************************************************************* *
- * ǥ쥯ȥꥳܥåȤ˴ؤؿ
+ * $B%G%#%l%/%H%j%3%s%\%&%#%8%'%C%H$K4X$9$k4X?t(B
  *
  * cb_combo_changed
  * cb_combo_set_dir
@@ -986,7 +987,7 @@ cb_mkdir_button_cancel (GtkWidget	*widget,
  * 
  * ************************************************************************* */
 
-/* ܥܥå򤵤Ƥ륢ƥबѹ줿Ȥν ************ */
+/* $B%3%s%\%\%C%/%9$NA*Br$5$l$F$$$k%"%$%F%`$,JQ99$5$l$?$H$-$N=hM}(B ************ */
 static void
 cb_combo_changed (GtkWidget	*widget,
 		  GtkWidget	*child,
@@ -1043,7 +1044,7 @@ cb_combo_set_dir (GtkWidget	*widget,
   return FALSE;
 }
 
-/* Ϥ줿ƥȤ򥳥ܥܥåΥƥɲ **************** */
+/* $B?7$7$/F~NO$5$l$?%F%-%9%H$r%3%s%\%\%C%/%9$N%"%$%F%`$KDI2C(B **************** */
 static void
 combo_list_add (GtkCustomIconFileSel	*parent,
 		const gchar		*folder) {
@@ -1075,7 +1076,7 @@ combo_list_add (GtkCustomIconFileSel	*parent,
   }
 }
 
-/* ܥܥå˥ƥ򥻥åȤ ************************************ */
+/* $B%3%s%\%\%C%/%9$K%"%$%F%`$r%;%C%H$9$k(B ************************************ */
 static void
 combo_set_popdown_strings (GtkCombo	*combo,
 			   GList	*strings,
@@ -1098,7 +1099,7 @@ combo_set_popdown_strings (GtkCombo	*combo,
 }
 
 /* ************************************************************************* *
- * Хؿ
+ * $B%0%m!<%P%k4X?t(B
  * ************************************************************************* */
 
 /* ************************************************************************* */
@@ -1148,7 +1149,6 @@ gtk_custom_icon_file_selection_set_dir (GtkCustomIconFileSel	*filesel,
   gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (filesel->dir_combo)->entry),
 		      real_path);
   combo_list_add (filesel, real_path);
-  
   g_free (real_path);
 
   return;
