@@ -3,19 +3,18 @@
  *
  * Copyright (C) 2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                    Time-stamp: <03/03/06 21:26:29 sugaya>
+ *                                    Time-stamp: <04/05/19 20:40:05 sugaya>
  * ************************************************************************* */
 #include "teoeyes.h"
 #include "init.h"
 #include "property.h"
 
-/* ************************************************************************* */
+/* 饤֥ν ****************************************************** */
 void
 teoeyes_init (int	argc,
 	      char	**argv) {
-  
   /*  */
-  bindtextdomain (GETTEXT_PACKAGE, LOCALE_DIR);
+  bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
