@@ -1,9 +1,9 @@
 /* ************************************************************** main.c *** *
- * ᥤؿ
+ * $B%a%$%s4X?t(B
  *
- * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
+ * Copyright (C) 2001-2004 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                  Time-stamp: <03/04/28 22:24:49 sugaya>
+ *                                  Time-stamp: <04/06/21 15:21:36 sugaya>
  * ************************************************************************* */
 #include "teoeyes.h"
 #include "callback.h"
@@ -14,31 +14,31 @@
 #include "option.h"
 #include "property.h"
 
-/* ꤵ줿طʲȤ褷λ **************************** */
+/* $B;XDj$5$l$?2hA|$rGX7J2hA|$H$7$FIA2h$7=*N;$9$k(B **************************** */
 static void
 set_wallpaper (GList	*list,
 	       gint	align) {
-  /* ɻ */
+  /* $BJI;f@_Dj(B */
   set_as_wallpaper (ti_get_file_path (list), align-1);
 
-  /* β */
+  /* $B%a%b%j$N2rJ|(B */
   teoeyes_free_option (to);
   config_free_file (tc);
   g_list_foreach (list, (GFunc) teoeyes_image_free, NULL); 
 
-  /* λ */
+  /* $B=*N;(B */
   exit (1);
 }
 
-/* ꤵ줿եƥɤ ************************************** */
+/* $B;XDj$5$l$?%U%!%$%k$rA4$F%m!<%I$9$k(B ************************************** */
 static void
 load_all_images (GList	*list) {
   GtkWidget		*progress_window;
-  GtkWidget		*progress_bar;    
+  GtkWidget		*progress_bar;
   GtkWidget		*vbox;
   GtkWidget		*align;
   GtkAdjustment		*adj;
-  GList			*tmplist;  
+  GList			*tmplist;
   gint			count;
   gint			max;
   gint			w, h;
@@ -46,7 +46,7 @@ load_all_images (GList	*list) {
   count = 0;
   max = g_list_length (list);
 
-  /* ץ쥹Сɽ */
+  /* $B%W%m%0%l%9%P!<$NI=<((B */
   {
     progress_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
     gtk_window_set_policy (GTK_WINDOW (progress_window), FALSE, FALSE, TRUE);
@@ -76,8 +76,8 @@ load_all_images (GList	*list) {
     gtk_widget_set_usize (progress_window, 200, -1);
     gtk_widget_set_uposition (progress_window, w, h);
     gtk_widget_show (progress_window);
-  }    
-  /* Υ */
+  }
+  /* $B2hA|$N%m!<%I(B */
   while (list) {
     count++;
     gtk_progress_bar_update (GTK_PROGRESS_BAR (progress_bar),
@@ -96,11 +96,11 @@ load_all_images (GList	*list) {
   gtk_widget_destroy (progress_window);
 }
 
-/* ɥΥȥ (-gץ) ************************* */
+/* $B%&%#%s%I%&$N%8%*%a%H%j@_Dj(B (-g$B%*%W%7%g%s;XDj;~(B) ************************* */
 static void
 set_geometry (GtkWidget	*window,
 	      TEOption	*to) {
-  int	rx, ry, rw, rh, rd;
+  gint	rx, ry, rw, rh, rd;
     
   if (to->geometry->width  != UNDEF_VAL && to->geometry->height != UNDEF_VAL) {
     gtk_widget_set_size_request (window,
@@ -122,50 +122,50 @@ set_geometry (GtkWidget	*window,
   }
 }
 
-/* ************************************************************************* */
+/* $B%a%$%s4X?t(B ************************************************************** */
 int
 main (int	argc,
       char	**argv) {
   
-  /*  */
+  /* $B=i4|2=(B */
   {
+    /* $B%i%$%V%i%j$N=i4|2=(B */
     teoeyes_init (argc, argv);
-
-    /* եɤ߹ */
+    /* $B@_Dj%U%!%$%k$NFI$_9~$_(B */
     tc = teoeyes_init_config ();
     if (!tc) exit (1);
-    /* ץ */
+    /* $B%*%W%7%g%s$N@_Dj(B */
     to = teoeyes_init_option ();
-    /* ν */
+    /* $B2hA|%m!<%@$N=i4|2=(B */
     loader_init (tc->loader_dirs);
   }
-  /* Υå */
+  /* $B0z?t$N%A%'%C%/(B */
   if (!getargs (argc, argv, &to, &tc)) usage ();
 
-  /* ɤ߹ */
+  /* $B2hA|$NFI$_9~$_(B */
   teoeyes_image_load (ti_get_image (image_list), to->frame, to->min, to->max);
 
-  /* طʤؤ (-rootץ) */
+  /* $BGX7J$X$NIA2h(B (-root$B%*%W%7%g%s(B) */
   if (to->wallpaper) set_wallpaper (image_list, to->wallpaper);
 
-  /* ƥɤ߹ (-lץ) */
+  /* $B2hA|$rA4$F%a%b%j$KFI$_9~$`(B (-l$B%*%W%7%g%s(B) */
   if (to->load_all && g_list_next (image_list)) {
     load_all_images (image_list->next);
   }
-  /* ɥ */
+  /* $B2hA|%&%#%s%I%&$N@8@.(B */
   image_window = image_window_new (_("TeoEyes"),
 				   ti_get_width  (image_list),
 				   ti_get_height (image_list));
   
-  /* ɥΥȥ (-g ץ) */
+  /* $B%&%#%s%I%&$N%8%*%a%H%j@_Dj(B (-g $B%*%W%7%g%s;XDj;~(B) */
   if (to->geometry) set_geometry (image_window, to);
 
-  /* ɥɽ */
+  /* $B%&%#%s%I%&$NI=<((B */
   gtk_widget_show (image_window);
 
-  /* ᥤ롼 */
-  gtk_main ();
-
+  /* $B%a%$%s%k!<%W(B */
+  gtk_main (); 
+  
   return 0;
 }
 
