@@ -87,7 +87,7 @@ confirm_box_show (GtkWidget	*parent,
   GtkWidget	*dialog;
   GtkWidget	*label;
   GtkWidget	*button;
-  gboolean	flag = TRUE;
+  gboolean	flag = FALSE;
   
   /*  */
   dialog = gtk_dialog_new ();
