@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                    Time-stamp: <03/05/15 15:54:01 sugaya>
+ *                                    Time-stamp: <04/04/26 13:17:53 sugaya>
  * ************************************************************************* */
 #include "teoeyes.h"
 #include "image_io.h"
@@ -14,7 +14,7 @@
 void
 do_backup (GList	*list) {
   TEImage	*ti;
-
+  
   ti = ti_get_image (list);
   if (!ti->backup) {
     ti->backup = gdk_pixbuf_copy (ti->pixbuf);
@@ -212,4 +212,11 @@ flip_vertical (GList	*list) {
   }
 }
 
+/* ************************************************************************* */
+void
+rotate_90 (GList	*list) {
+  
+}
+
+
 /* ********************************************************* operation.c *** */
