@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                    Time-stamp: <02/06/28 16:33:54 sugaya>
+ *                                    Time-stamp: <04/06/22 04:14:50 sugaya>
  * ************************************************************************* */
 #include <teo.h>
 #include "teoeyes.h"
@@ -14,15 +14,21 @@
 
 #define	MIN_SPEED	1
 #define	MAX_SPEED	1000
-#define	DEFAULT_SPEED	50
+#define	DEFAULT_SPEED	10
+#define	SPEED_PARAM	1000
 
 /* ؿ ************************************************************ */
 static void	player_update_controller	(gint		value);
 static void	player_show_nth 		(gint		n);
 static void	player_show_next		(void);
 static void	player_show_previous		(void);
+#if 1
 static void	play_forward			(void);
 static void	play_backward			(void);
+#else
+static void*	play_forward_thread 		(void		*data);
+static void*	play_backward_thread 		(void		*data);
+#endif
 static void	start_play_forward		(void);
 static void	start_play_backward	 	(void);
 static void	stop_play_image			(void);
@@ -126,8 +132,11 @@ static FontData*	font_new		(gchar		*filename,
 						 gint		area);
 static SkinData*	player_skin_new		(gchar		*skin_data);
 
-static gint		play_timer;
+static gint		play_timer = 0;
 static gint		play_speed = DEFAULT_SPEED;
+#if 0
+static GThread		*thread_id = NULL;
+#endif
 static gint		repeat_flg;
 
 static const gchar	iso_ascii[] = {
@@ -221,11 +230,7 @@ player_show_previous (void) {
     /* βɽ */
     if (g_list_previous (image_list)) {
       image_list = g_list_previous (image_list);
-      if (g_list_length (ti_get_pixbuf_list (image_list)) == 1) {
-	teoeyes_image_load (ti_get_image (image_list), -1, to->min, to->max);
-      } else {
-	teoeyes_image_set (ti_get_image (image_list), -1, to->min, to->max);
-      }
+      teoeyes_image_set (ti_get_image (image_list), -1, to->min, to->max);
       set_font_text (player, ti_get_filename (image_list));
       player_update_controller (g_list_length
 				(g_list_first(image_list))-
@@ -238,6 +243,7 @@ player_show_previous (void) {
 			       ti_get_height (image_list));
 }
 
+#if 1
 /* ꥹȤϢ³ɽ() ******************************************** */
 static void
 play_forward (void) {
@@ -279,7 +285,57 @@ play_forward (void) {
 			       ti_get_width  (image_list),
 			       ti_get_height (image_list));
 }
+#else
+/* ꥹȤϢ³ɽ() ******************************************** */
+static void*
+play_forward_thread (void	*data) {
 
+  while (play_timer) {
+    gdk_threads_enter ();
+    
+    if (ti_get_frame (image_list) < ti_get_nframes (image_list) - 1) {
+      /* ޥե졼TEOļΥե졼ब... */
+
+      /* Υե졼ǡΥå */
+      if (g_list_length (ti_get_pixbuf_list (image_list)) == 1) {
+	teoeyes_image_load (ti_get_image (image_list),
+			    ti_get_frame (image_list) + 1, to->min, to->max);
+      } else {
+	teoeyes_image_set (ti_get_image (image_list), 
+			   ti_get_frame (image_list) + 1, to->min, to->max);
+      }
+    } else if (g_list_next (image_list)) {
+
+      /* β... */
+      image_list = g_list_next (image_list);
+      teoeyes_image_set (ti_get_image (image_list), 0, to->min, to->max);
+      set_font_text (player, ti_get_filename (image_list));
+      player_update_controller (g_list_length(g_list_first(image_list))-
+				g_list_length (image_list));
+      
+    } else if (repeat_flg) {
+      
+      /* ֤⡼ɤξ... */
+      image_list = g_list_first (image_list);
+      teoeyes_image_set (ti_get_image (image_list), 0, to->min, to->max);
+      set_font_text (player, ti_get_filename (image_list));
+      player_update_controller (0);
+
+    } else {
+      /*  */
+      if (play_timer) play_timer = 0;
+    }
+    /*  */
+    gtk_widget_set_size_request (get_widget (image_window, "canvas"),
+				 ti_get_width  (image_list),
+				 ti_get_height (image_list));
+    usleep (play_speed * SPEED_PARAM);
+    gdk_threads_leave ();    
+  }
+  return NULL;
+}
+#endif
+#if 1
 /* ꥹȤϢ³ɽ() ******************************************** */
 static void
 play_backward (void) {
@@ -297,22 +353,14 @@ play_backward (void) {
   } else if (g_list_previous (image_list)) {
     /* β... */
     image_list = g_list_previous (image_list);
-    if (g_list_length (ti_get_pixbuf_list (image_list)) == 1) {
-      teoeyes_image_load (ti_get_image (image_list), -1, to->min, to->max);
-    } else {
-      teoeyes_image_set (ti_get_image (image_list), -1, to->min, to->max);
-    }
+    teoeyes_image_set (ti_get_image (image_list), -1, to->min, to->max);
     set_font_text (player, ti_get_filename (image_list));
     player_update_controller (g_list_length(g_list_first(image_list))-
 			      g_list_length (image_list));
   } else if (repeat_flg) {
     /* ֤⡼ɤξ... */
     image_list = g_list_last (image_list);
-    if (g_list_length (ti_get_pixbuf_list (image_list)) == 1) {
-      teoeyes_image_load (ti_get_image (image_list), -1, to->min, to->max);
-    } else {
-      teoeyes_image_set (ti_get_image (image_list), -1, to->min, to->max);
-    }
+    teoeyes_image_set (ti_get_image (image_list), -1, to->min, to->max);
     set_font_text (player, ti_get_filename (image_list));
     player_update_controller(g_list_length(g_list_first(image_list))-1);
   } else {
@@ -325,21 +373,77 @@ play_backward (void) {
 			       ti_get_width  (image_list),
 			       ti_get_height (image_list));
 }
+#else
+/* ꥹȤϢ³ɽ() ******************************************** */
+static void*
+play_backward_thread (void	*data) {
+  while (play_timer) {
+    gdk_threads_enter ();
+    
+    if (ti_get_frame (image_list) > 0) {    
+      /* ޥե졼TEOΥե졼ब... */
 
+      /* Υե졼ǡΥå */
+      if (g_list_length (ti_get_pixbuf_list (image_list)) == 1) {
+	teoeyes_image_load (ti_get_image (image_list),
+			    ti_get_frame (image_list) - 1, to->min, to->max);
+      } else {
+	teoeyes_image_set (ti_get_image (image_list),
+			   ti_get_frame (image_list) - 1, to->min, to->max);
+      }
+    } else if (g_list_previous (image_list)) {
+      /* β... */
+      image_list = g_list_previous (image_list);
+      teoeyes_image_set (ti_get_image (image_list), -1, to->min, to->max);
+      set_font_text (player, ti_get_filename (image_list));
+      player_update_controller (g_list_length(g_list_first(image_list))-
+				g_list_length (image_list));
+    } else if (repeat_flg) {
+      /* ֤⡼ɤξ... */
+      image_list = g_list_last (image_list);
+      teoeyes_image_set (ti_get_image (image_list), -1, to->min, to->max);
+      set_font_text (player, ti_get_filename (image_list));
+      player_update_controller(g_list_length(g_list_first(image_list))-1);
+    } else {
+      /*  */
+      if (play_timer) play_timer = 0;
+    }
+    /*  */
+    gtk_widget_set_size_request (get_widget (image_window, "canvas"),
+				 ti_get_width  (image_list),
+				 ti_get_height (image_list));
+    usleep (play_speed * SPEED_PARAM);
+    gdk_threads_leave ();
+  }
+  return NULL;
+}
+#endif
 /* ץ쥤ܥ󤬲줿ν ****************************************** */
 static void 
 start_play_forward (void) {
+#if 1
   if (play_timer != 0) return;
   play_timer = gtk_timeout_add (play_speed,
 				(GtkFunction) play_forward, NULL);
+#else
+  if (play_timer != 0) return;
+  play_timer = 1;
+  thread_id = g_thread_create (play_forward_thread, NULL, FALSE, NULL);
+#endif
 }
 
 /* Хåܥ󤬲줿ν ****************************************** */
 static void
 start_play_backward (void) {
+#if 1
   if (play_timer != 0) return;  
   play_timer = gtk_timeout_add (play_speed,
 				(GtkFunction) play_backward, NULL);
+#else
+  if (play_timer != 0) return;
+  play_timer = 1;
+  thread_id = g_thread_create (play_backward_thread, NULL, FALSE, NULL);  
+#endif
 }
 
 /* ȥåץܥ󤬲줿ν **************************************** */
@@ -349,15 +453,24 @@ stop_play_image (void) {
   play_timer = 0;
 }
 
+/* ************************************************************************* */
+static gboolean
+delete_event_func (GtkWidget	*widget,
+		   gpointer	data) {
+  return FALSE;
+}
+	     
 /* ץ졼Ĥ ******************************************************** */
 static void
 exit_player (void) {
-  stop_play_image ();
-  gtk_widget_hide (player);
-  gtk_widget_destroy (player);
-  player = NULL;
-  if (update_timer) gtk_timeout_remove (update_timer);
-  update_timer = 0;
+  if (player) {
+    stop_play_image ();
+    gtk_widget_hide (player);
+    gtk_widget_destroy (player);
+    player = NULL;
+    if (update_timer) gtk_timeout_remove (update_timer);
+    update_timer = 0;
+  }
 }
 
 /* ®٤ ********************************************************** */
@@ -676,9 +789,6 @@ player_mouse_released (GtkWidget		*widget,
     break;
   case 7:
     exit_player ();
-#if 0      
-    draw_button (widget, skin->exit_button, 2);
-#endif
     break;
   default:
     break;
@@ -1344,11 +1454,13 @@ player_new (gchar	*skin_data) {
 			 GDK_POINTER_MOTION_MASK |
 			 GDK_BUTTON_PRESS_MASK |
 			 GDK_BUTTON_RELEASE_MASK);
-
+#if 0
   gtk_signal_connect (GTK_OBJECT (window), "destroy",
 		      (GtkSignalFunc) exit_player, NULL);
+#endif
   gtk_signal_connect (GTK_OBJECT (window), "delete_event",
-		      (GtkSignalFunc) exit_player, NULL);
+		      (GtkSignalFunc) delete_event_func, NULL);
+
   gtk_signal_connect (GTK_OBJECT (window), "motion_notify_event",
 		      (GtkSignalFunc) player_mouse_motion, NULL);
   gtk_signal_connect (GTK_OBJECT (window), "button_press_event",
