@@ -3,7 +3,7 @@
  *
  * Copyright (C) 1998-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
  * Okayama University
- *                                  Time-stamp: <03/04/28 23:19:34 sugaya>
+ *                                  Time-stamp: <04/06/22 02:30:22 sugaya>
  * ************************************************************************* */
 #include <dirent.h>
 #include <unistd.h>
@@ -173,7 +173,7 @@ plugin_menu_new (GtkMenuItem	*menu1,
       /* ץ饰ɤ߹ */
       handle = dlopen (plugin_path, RTLD_LAZY);
       if (!handle) {
-	g_printerr (_("TeoEyes Plugin %s cannot be loaded !\n"), plugin_path);
+	g_printerr (_("TeoEyes Plugin %s could not be loaded.\n"), plugin_path);
 	g_free (plugin_path);
 	p_list_ptr = g_list_next (p_list_ptr);
 	continue;
@@ -184,7 +184,7 @@ plugin_menu_new (GtkMenuItem	*menu1,
       /* ץ饰γ */
       p = dlsym (handle, "plugin_info");
       if (!p) {
-	g_printerr (_("Plugin Information in %s is not found !\n"),
+	g_printerr (_("Plugin Information in %s was not found.\n"),
 		    plugin_path);
 	g_free (plugin_path);	  
 	p_list_ptr = g_list_next (p_list_ptr);
